(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    744364,      20621]
NotebookOptionsPosition[    730660,      20198]
NotebookOutlinePosition[    731040,      20215]
CellTagsIndexPosition[    730997,      20212]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Quit", "[", "]"}], "*)"}]], "Input",
 CellChangeTimes->{{3.508755409347063*^9, 3.508755412111178*^9}, {
  3.509359618083904*^9, 3.509359618244153*^9}, {3.511078549197713*^9, 
  3.51107855202983*^9}, {3.548517567488236*^9, 3.54851757279426*^9}}],

Cell["\<\
We intend to perform the 3+1 decomposition of Einstein\[CloseCurlyQuote]s \
equations non-minimally coupled to a scalar field. The equations of motion \
result from the dimensional reduction of D-dimensional EEs on a S^{D-4} \
sphere. We perform the split using the xtensor package (J.M. Martin Garcia et \
al \[OpenCurlyQuote]02-\[OpenCurlyQuote]13) for mathematica.  The package can \
be downloaded here: http://www.xact.es/ 
This website also offers good documentation and example notebooks.\
\>", "Text",
 CellChangeTimes->{{3.571486994236559*^9, 3.571487060480845*^9}, {
  3.571487110272914*^9, 3.571487144425509*^9}, {3.572691288702155*^9, 
  3.572691321595433*^9}, {3.572692323584239*^9, 3.5726923933161917`*^9}}],

Cell[CellGroupData[{

Cell["Loading xtensor", "Section",
 CellChangeTimes->{{3.509192873063336*^9, 3.509192880640576*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s start by loading the xtensor package into mathematica:\
\
\>", "Text",
 CellChangeTimes->{{3.571487148960648*^9, 3.5714871624265757`*^9}, 
   3.571487219258821*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"<<", "xAct/xTensor.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "xAct/ExpressionManipulation.m"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.506614860932121*^9, 3.506614869697944*^9}, {
   3.507035687673432*^9, 3.507035688602207*^9}, 3.507546232847082*^9, {
   3.507979310039011*^9, 3.507979320390522*^9}, {3.5714871903158617`*^9, 
   3.571487190935259*^9}}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCA9MbmsIhFIAwCazd0F
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2012", ",", "5", ",", "5"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.1.3", ", ", {2012, 5, 5}],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCBdZ1lekQikAZkV3Mk=
  "]],

Cell[BoxData["\<\"CopyRight (C) 2003-2011, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCAt5FdekQikAZZI3HI=
  "]],

Cell[BoxData["\<\"Connecting to external linux executable...\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCC9Q6eiIhFIAwCakNz3
  "]],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCCdoFxZkQikAZeX3Jc=
  "]],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCD9xrqyIhFIAwCcn907
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.0.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2012", ",", "5", ",", "5"}], "}"}]}],
  SequenceForm["Package xAct`xTensor`  version ", "1.0.4", ", ", {2012, 5, 5}],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCDNFFZZkQikAZYM3Gw=
  "]],

Cell[BoxData["\<\"CopyRight (C) 2002-2011, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCC9O7+yIhFIAwCcg90+
  "]],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCBd11BZkQikAZsS3RI=
  "]],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCBtNbWyIhFIAwCZhdzj
  "]],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwAuKDTYz3pJVeOXq3zgmTAdKWYeZlIDrndXItiP4afbQH
RN+SluaXBdLHFi3WrgHSwo9+rK0H0gujv8g0AOm+/RFX3gPpRofY9g9Aevbn
uZe8lF85BphPr85WeeWYPidNQED1lWPWDG05RyC95cTuxklA+l9d2BRrNSCf
z1xmP5CWmeEeaaX+ytGfefKMFCCdbnbCaAuQXm4bde0RkA5ty5Fo0XjlOOXA
RJ/1QHqdNvuVm0D6zJa8+ayarxx1RcQzpwDpgrtOvtuBdNml3Ms6Wq8cXbrM
vxoBadn+8F+RQFryafU1Ru1Xjk7/EtYzAWmdlTwbWYC04MdNP4OA9L9w/YXe
eq8c/dZ25B8yfOXoFbtD5TWQ7v2XcvkdkL76/cI7SaNXjnVPFtbIAukVSaJT
nApeOar8VJ4Jog1z5aslC185Ln5x13j+7FeOWh48C0D0grsbYrnnvHI8Lnud
TQBIx/oL2ggB6ZA5K8KFgXSHiM3q20BaS8rUIG4eMNw/JW0D0RnNnBdBdMCE
0IPxQFrwr8w9EP1RYPW7BCC9anVlRSKQBgCdn91p
  "]]
}, Open  ]],

Cell["\<\
We want to 
(i)make sure that  indices are output in a nice form,
(ii) specify the sign convention for the extrinsic curvature, such that \
$K_{ab} = - 1/2 \[ScriptCapitalL]_{u} \[Gamma]_{ab}$
(iii) specify the sign convention for the acceleration
We can perform these specifications with the following commands:\
\>", "Text",
 CellChangeTimes->{{3.571487235488202*^9, 3.571487273530356*^9}, {
  3.5714873131203012`*^9, 3.57148747353636*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$ExtrinsicKSign", "=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$AccelerationSign", "=", 
   RowBox[{"-", "1"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.507124652012831*^9, 3.507124652651008*^9}, 
   3.507546232847902*^9, {3.507740275965741*^9, 3.507740276448632*^9}, {
   3.571489478408149*^9, 3.571489478967716*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.50754570847394*^9, 3.507545742228155*^9}, {
  3.507545799415026*^9, 3.50754581382384*^9}, {3.507740287094178*^9, 
  3.507740303398833*^9}, {3.507990200838178*^9, 3.507990201231651*^9}, {
  3.548517535857148*^9, 3.548517538811791*^9}}],

Cell[CellGroupData[{

Cell["Definitions of manifold, 4 - metric and tensors", "Subsection",
 CellChangeTimes->{3.509192970613252*^9}],

Cell["\<\
Here we define the spacetime { M, gg_{ab} } on the 4-dimensional manifold $M$ \
with spacetime metric $ gg_{ab} $. The signature is specified as {-,+,+,+}. \
The covariant derivative with respect to $gg_{ab}$ is denoted as \
\[OpenCurlyDoubleQuote]CD\[CloseCurlyDoubleQuote].
We also specify a list of characters used as indices throughout our \
computations.
The spacetime dimension $D$ is denoted by the symbol \
\[OpenCurlyDoubleQuote]Dim\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.57148749362014*^9, 3.571487667499951*^9}, {
  3.572694550718544*^9, 3.572694586533349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefConstantSymbol", "[", "Dim", "]"}]], "Input",
 CellChangeTimes->{{3.572692746909422*^9, 3.572692759140506*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "Dim", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`Dim, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572692760212225*^9, 3.572694591183042*^9, 
  3.5726947736720257`*^9, 3.5726969546161327`*^9, 3.572698060257506*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Index", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ToExpression", "[", 
        RowBox[{"\"\<r\>\"", "<>", 
         RowBox[{"ToString", "[", "i", "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "100"}], "}"}]}], "]"}], ",", 
     RowBox[{"IndexRange", "[", 
      RowBox[{"a", ",", "r"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.509359418143659*^9, 3.509359442006362*^9}, {
  3.509715278799914*^9, 3.509715279704382*^9}, {3.511168061489516*^9, 
  3.511168062061609*^9}}],

Cell[BoxData[{
 RowBox[{"DefManifold", "[", 
  RowBox[{"M", ",", "4", ",", "Index"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefMetric", "[", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"gg", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", 
    RowBox[{"PrintAs", "\[Rule]", "\"\<g\>\""}]}], "]"}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.506615012185108*^9, 3.50661501541816*^9}, {
   3.50661505164811*^9, 3.506615060938743*^9}, {3.506615322911528*^9, 
   3.506615326268799*^9}, {3.506618962185023*^9, 3.506618963310575*^9}, {
   3.507034564835126*^9, 3.507034565182109*^9}, {3.50703495706967*^9, 
   3.507034986666243*^9}, {3.507035592883887*^9, 3.507035610469533*^9}, {
   3.507035674024977*^9, 3.50703567498374*^9}, {3.507046937625186*^9, 
   3.507046939014417*^9}, {3.507460854743226*^9, 3.507460855360201*^9}, 
   3.507545827262238*^9, 3.508755392345878*^9, {3.548517558865815*^9, 
   3.548517560245598*^9}, {3.571473144471417*^9, 3.571473144840426*^9}, {
   3.57269262276855*^9, 3.5726926230880938`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "M", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", "manifold ", $CellContext`M,
    ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062683638*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentM", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentM, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062728798*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"gg", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`gg[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062785928*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"epsilongg", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilongg[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062817131*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetragg", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Tetragg[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.5726980628197107`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetragg\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Tetragg\[Dagger][-$CellContext`a, -$CellContext`b, \
-$CellContext`c, -$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062821772*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"CD", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`CD[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.57269806282393*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionCD[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062825984*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelCD", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelCD[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062828465*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"RiemannCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`RiemannCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.57269806283062*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.5726980628327*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062834519*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062836783*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062875093*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"EinsteinCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Einstein tensor ", 
   $CellContext`EinsteinCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698062878433*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"WeylCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`WeylCD[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.5726980629201603`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRicciCD[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.5726980630658073`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"KretschmannCD", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`KretschmannCD[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698063105981*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.5726980631084747`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698063255913*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698063295908*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Detgg", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Detgg[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.508755439891263*^9, 3.508838989361695*^9, 3.509092508999783*^9, 
   3.509192992174096*^9, 3.509358959362299*^9, 3.509359642466448*^9, 
   3.509450056604806*^9, 3.509715281076472*^9, 3.50996833182166*^9, 
   3.509975620816596*^9, 3.510047942289649*^9, 3.510227677381098*^9, 
   3.510303509725778*^9, 3.510314193773816*^9, 3.510318578164516*^9, 
   3.510477216878158*^9, 3.510568019420743*^9, 3.510572746168135*^9, 
   3.510574143218631*^9, 3.510903012523537*^9, 3.510991482104755*^9, 
   3.510991536973898*^9, 3.511078561164714*^9, 3.51116806335437*^9, 
   3.511168262826358*^9, 3.511457648025755*^9, 3.511460691694679*^9, 
   3.511513095621025*^9, 3.511532149072094*^9, 3.5117795916513777`*^9, 
   3.5117854908981667`*^9, 3.5118653095468397`*^9, 3.512209088496746*^9, 
   3.512210811989977*^9, 3.512214921294536*^9, 3.5123752476157293`*^9, 
   3.5139330663914213`*^9, 3.515749246250967*^9, 3.515832692258595*^9, 
   3.515840163211926*^9, 3.5159284502346077`*^9, 3.5159357183595057`*^9, {
   3.548517552155944*^9, 3.548517579524918*^9}, 3.548957658209902*^9, 
   3.571251626859899*^9, 3.5712524938443947`*^9, 3.571473145549079*^9, 
   3.571482682644367*^9, 3.571487670916703*^9, 3.571489482803897*^9, 
   3.571899747381465*^9, 3.572691337958807*^9, 3.572692412066567*^9, 
   3.572692625465026*^9, 3.572694592886691*^9, 3.572694775047997*^9, 
   3.5726969561946774`*^9, 3.572698063298193*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions of  the 3 - metric and tensors", "Subsection",
 CellChangeTimes->{3.509193150038602*^9}],

Cell["\<\
Next, we define the normal vector $ u^a $ and specify the normalization \
$u_{a} u^{a} = -1$\
\>", "Text",
 CellChangeTimes->{{3.571487686242887*^9, 3.571487747883348*^9}, {
  3.572694777650119*^9, 3.572694780828208*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"u", "[", "a", "]"}], ",", "M"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"u", "/:", 
  RowBox[{
   RowBox[{"u", "[", "a_", "]"}], " ", 
   RowBox[{"u", "[", 
    RowBox[{"-", "a_"}], "]"}]}], ":=", 
  RowBox[{"-", "1"}]}], "\n", 
 RowBox[{"u", "/:", 
  RowBox[{
   RowBox[{"u", "[", "a_", "]"}], " ", 
   RowBox[{"u", "[", "b_", "]"}], " ", 
   RowBox[{"gg", "[", 
    RowBox[{
     RowBox[{"-", "a_"}], ",", 
     RowBox[{"-", "b_"}]}], "]"}]}], ":=", 
  RowBox[{"-", "1"}]}], "\n", 
 RowBox[{"u", "/:", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"-", "a_"}], "]"}], " ", 
   RowBox[{"u", "[", 
    RowBox[{"-", "b_"}], "]"}], " ", 
   RowBox[{"gg", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}]}], ":=", 
  RowBox[{"-", "1"}]}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.506615046495383*^9, 3.506615048366156*^9}, {
   3.506615241600169*^9, 3.506615267903901*^9}, {3.50661896839224*^9, 
   3.506618977149284*^9}, {3.507035447057529*^9, 3.507035503309965*^9}, {
   3.507035573621105*^9, 3.50703557392478*^9}, {3.507046990746665*^9, 
   3.507047006636181*^9}, {3.507114085172676*^9, 3.507114090879157*^9}, {
   3.5071141272245*^9, 3.507114128550052*^9}, {3.507114163398957*^9, 
   3.507114163689026*^9}, 3.507545839056263*^9, {3.507987558155572*^9, 
   3.507987559893334*^9}, 3.507989389158964*^9, 3.507989854667462*^9, {
   3.508764330204931*^9, 3.508764346322248*^9}, {3.509359506454317*^9, 
   3.509359507900944*^9}, 3.548957739439843*^9, {3.571487753368607*^9, 
   3.5714877589715014`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"u", "[", "a", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`u[$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5714894864218807`*^9, 3.5718997524455*^9, 
  3.57269134027814*^9, 3.572692416112899*^9, 3.5726926285466137`*^9, 
  3.572694595835265*^9, 3.572694781787141*^9, 3.572696958951654*^9, 
  3.572698067132914*^9}],

Cell["\<\
Now, we define the induced metric $hh_{ab}$ on the spatial slice $\
\[CapitalSigma]_t$  which is induced from $gg_{ab}$ using the vector $u^a$ \
normal to the hypersurface. Because $hh_{ab}$ is a spatial metric the \
signature now is {+,+,...,+} . We denote the covariant derivative with \
respect to $hh_{ab}$ as \[OpenCurlyDoubleQuote]cd\[CloseCurlyDoubleQuote], \
while throughout the notebook it will be shown as \[OpenCurlyDoubleQuote]D\
\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.571487777194007*^9, 3.571487985602668*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefMetric", "[", 
  RowBox[{"1", ",", 
   RowBox[{"hh", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "cd", ",", 
   RowBox[{"SymbolOfCovD", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<|\>\"", ",", "\"\<D\>\""}], "}"}]}], ",", 
   RowBox[{"InducedFrom", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"gg", ",", "u"}], "}"}]}], ",", 
   RowBox[{"PrintAs", "\[Rule]", "\"\<h\>\""}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.507545839056534*^9, {3.510227724258123*^9, 3.510227727261679*^9}, {
   3.548517630391494*^9, 3.548517637002994*^9}, {3.5714731746107073`*^9, 
   3.571473174948514*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"DefMetric", "::", "old"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are already metrics \
\[NoBreak]\\!\\({gg}\\)\[NoBreak] in vbundle \[NoBreak]\\!\\(TangentM\\)\
\[NoBreak].\"\>"}]], "Message", "MSG",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->CompressedData["
1:eJwVx11MklEcgPGXkMbKGWK20dSiMEwzgWoju4BTq62gZKxpsQb6SlbQEMoh
OY25WXMLx3q1bFb4NW9ayNj8ihTJZnlhy5pbaZmGaXWcZTDIWm79z8Wz3x4h
Xa49z6Io6iQkPpOfsSLEyKKXnCJumeYwv8AX0tG6CNh5Rx0kMiZ5XhTUvNSf
JtrFVQai7QvtIIYViewYaF5zVcfB1EBuStoOjFSMs4h4cCJuJ26okFwnBvw1
DUTv688zRMVivyUG9k0/nj2xE6OuzmapSYTRoXv2WjM4q7lQ0AQ6Q5vSeZkY
tTyvliNwfXIqw4CFpV9DjaDb6PUGwaNWWZ5yF0bLx66NPwUXHo4WDIPmRypP
GPTLNtP5YoyWSkKXDOA23ZU2Iygpi42Ugd/Y9fIe0FFPu+fAonPtn8Lgq9sZ
DfOgeIgnrMvCqCah96wPXJU5J6fIXyx2c3ZjFGUEXcTcy4kRBhwfiFqawNiY
iNMNbs2KaPvBgNqWKcnGqHJRzN0HFh5YYOnAFtfHGVYORu/jg7514JMjlf4E
sLtC+1cLJi03t6v2YuQzaawjUox4Oe/2L4GMXpn8E/wxSP0WyDC6OVlemw7+
8wbbDlsxUv+Z7xHYMFpr5Ctb72N0S093EG+8OV668QFGXDvF5YEue1IrH3QY
BboUEHdc9X4AA9ufSfUe+O+KAaInOPGWuHrXN2YAh9PYc0RRNn+lGNwzNVRV
Av4Hj9AsAQ==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"hh", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`hh[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6Ynv91YlAmkAa07F3Q==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"epsilonhh", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilonhh[-$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQAaS/O/VWJQBoAYtjEsg==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrahh", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Tetrahh[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EABfDNKFIuo7RJosaGjM3DrKl9ysMiMnlAYXMpJf6GREkrySWt
ltxzKw9kW2Yht82iPKCRlDTWmPIpJJd4cv4Pp1+dOnWS9K3aBi6Hw5EjZ06r
5UBESZhHJlWnUDJl7j7dhZ6L4xIn3FUUzfmhqzlWr0ylZMjvaqqBGb2GhXpY
NfLlboQrZFDhgM9HepMPSscW7/wwQZM4+gA3JqOT+sWUBMdvVtigTNV3dQOV
dp0pRELJ9L1wmVWgivgww528r5YxmDMgCrHC94MP7RYsTzaIstIomV0Vh8rh
02eAWwn787xebjolcdx9WxAs/u1aD4Yqo/ZPCw3fE4uFmZTskVLGnY1++Cbn
BQaZ1dFvMLeM9yOQUdLTyxgTYGSdcyGfoeQ17tEhaKNEvsxXz89g16lfYl0L
aOrCZynpGOeERsHVlYh5PqxKEVbGQMl5u+UWmjYPs6vn8PdKvc1qvfZcsjI2
20kNzCrg+ViFpfz3WmhnXD06+A9o78WC
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tetrahh\[Dagger]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Tetrahh\[Dagger][-$CellContext`a, -$CellContext`b, \
-$CellContext`c, -$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6ZyOA1WJQBoAZ2fFVA==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   
   RowBox[{"cd", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`cd[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6W+zD1QlAmkAbDzF8Q==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Torsioncd", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`Torsioncd[$CellContext`a, -$CellContext`b, -$CellContext`c], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6bO7D1YlAmkAa9rF6Q==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Christoffelcd", "[", 
    RowBox[{"a", ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`Christoffelcd[$CellContext`a, -$CellContext`b, \
-$CellContext`c], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6YrrB6sSgTQAafbFsA==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Riemanncd", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`Riemanncd[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6Tf+h6sSgTQAaerFng==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Riccicd", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`Riccicd[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQAaSu9Y1WJQBoAY4XEzg==
  "]],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EABfBtKFLDqLVJmpp7LpsHNLVPeRCRyYMpYxulxAyJktSSS1ot
uceoPUxsuTRyG4t4QCOpJawN5VNoucST8384/erUqSNStyoa2CwWS4qcO20r
+2JKwtySTHkiJVOm7rMd6L48LnfCndzSOR88aI5R5ydRMuQ7aFLB9F69WQtr
Rr5cjdBKBnM34MuR2uiFmWML9z4YVxw/6ofrk1EiQzIlwbGOajuUyPquPTB/
rd4YkkLJ9IPQwiiQcQMmuF3w1TIGcwbEITb4sR9QbMKqBL04K5WS2aXkUCl8
/nxiK6Gh4O6OnUYJn71n58Cy367VYCjrV/wpoP57YqEkg5JdUqFzZaMf9uS8
Qo5JHvUO8yqDfgQSSnp6df1xMELjNBfqKHnjP24I2iiRWnjy+RnsOtWLjMtP
xZrwWUo6xlmhkXDJyp3nwZpEoTIaply0r9xCo+Mwu3YOf6/lW4y2G/cVo85u
P1XBrKIgL6OwgvdRB7X+k556+A9pzsWu
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarcd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarcd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EABfDNKFLYKG1aouae3TygrfYpD4vI5IGVy4ZSYoZELSnJJa2W
3HMrDxZbWCO3sSgKjZaSxppL+RSSSzw5/4fTr06dOgm6Zk0dm8ViyZEzl21l
T0RJmEcmViVRMmHpPN2GnoujYhfczi6cCcD9xhhdbjIlA4H9hiqYYTLO1ULt
0Je7Hi6R/mwHfD7Umf1QPDJ/G4BCdfzwPVwf5yb0plASHOcst0OZott7DXPX
aswhqZRM3gkWGfmKiA8L3FJ+NY3ArD5RiA2+731oNmBZolEkSaNk2poSKodP
n4/sCtir9PnY6ZTEsnftQbDot2M1GCp6NH8aaPwemy/IpGSHlBjcUvSD11kv
MMii4r7BnFLOD19GSZfJ0COEkXrXXJ6BktfYBwe/hRL5Ik81O4Vdu26BcflR
rQ+fpqRtlBUaBa1LEbM8qE0SVETD1PPWlRtodh5IK2fw16vaZLRdeS4ZDXb7
cRWU5HP8jIIS3ns1LM486aqB/2Q/xOY=
  "]],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQAaQbnk1WJQBoAYlrErA==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Einsteincd", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Einstein tensor ", 
   $CellContext`Einsteincd[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6cKwk1WJQBoAZmfFMA==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Weylcd", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}], ",", 
     RowBox[{"-", "c"}], ",", 
     RowBox[{"-", "d"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Weyl tensor ", 
   $CellContext`Weylcd[-$CellContext`a, -$CellContext`b, -$CellContext`c, \
-$CellContext`d], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6QM/TlclAmkAbVnGIw==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRiccicd", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRiccicd[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQAaYmyq1WJQBoAZMfFAw==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"Kretschmanncd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`Kretschmanncd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EABfD/hiLlMmptkqixIWbzMJrapzyIyOTBFDaXUmKGZCUpySWt
ltyzUR6ILZeQYSPKAxpJJKy5lE+xZMST8384/erUqROva1bXcRiGkSOnTtvy
noiSELcsXZVIyYS588QB3edHxU7oUBTOeKGrMVqXnUTJgNfVUAVTuwzWWlgx
5D+ohwukX7EOXw91Jg9MH5m998LY/LjhR7g2HhnfK6YkMGaj3A5lyu7LG5i9
qjUFSSiZfBDOswqUYZ9muJ3jbxqBmX2iIBv07X2qN2FZgkEkTaZkelEcLIcv
X88cDezNubvjpFDC5+zaubDot2MlECp71H9qaPgemy1Io2SHlOgPMtAP3mS+
Qa5ZFfkBs0oDfgQySoxd+p5YGF7jtObqKXnnP60LWiiRz/NUlins2nVzrEvP
+TWh05S0jTLBEXBxIczCgxWJQk0UlJy1Lt9C08Z+RuUM/l6qtlhtV+4LVr3d
flwFpXkBHlZhCc9XDV+Za6MW/gNoJ8Vh
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuKz+9et3af6ypHzgpG+g9orx5mTKs/sBtIXLh713w+k
d1v4zHsEpA/kiCRZqb9y7Hx0IDMeSOvUFi1IAdLR3V8PpQHplY4dFluA9Msj
Sf0PgLT+lIX3HgFpWU/53sdAevMMQcUWjVeOLNLbItcDaSOb+is3gbTVpsR+
Vs1XjrPuSy0F0ZI2fJ8mAeldtl/zpgBpkzZV1nVA+sO+T0HbgXSoUpGqgdYr
xzmrNDiMgfSzL08Zo4B0i+3du4zarxzFGfeuZwLSfj/LN7IAaZvGoF9BQLro
2/SF3nqvHPc4BhYcMgSKd900eQ2kmSY5CL4H0pbBzN8ljV45VtUWNMoCaf7k
/QucCl45vhN/skWy8JWj8VIhh/mzgfpKkxaB6DVPPZO557xyLJnGwCEApFet
5JsvBKSj1aSihIG05rnitbeBdP+2g4Zx84DuveKwA0Svu3bhEoguWL/+RDyQ
NnBlfgCipQKFPiQA6asiN6oSgTQAaBPFYQ==
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlkow3EAB/AdFCnHqLVJoubOLg9oaj/lYYg2eTDlmKOUmCFRkpIcabWW
c7EpD8SWo5FhiPKARlJLWHOUn0LLEU++/4dvn/rWt74JulZNA5vFYsmRM7d9
ZU9ESahHJlYmUTJl6j51Qc/FcakburKLZ/1wvzlGl5tMybB/v6kaZvQarPWw
cvTrsBEukqHsDfhypDP6oNhsu/PDOFX82ANcn4xKGEihJCjWWeGAMkXflRfm
rtUag1Mpmb4XLjAKFOEBE9zO+2oxw6xBUbAdfuwFNJuwPNEgkqRRYllKCZHD
588nthYO5N3estMp4bN3HRxY8tu1GgQV/Zo/DTR8T9iKMinZIWr9oRT9iDfr
FXJMyqh3mFPG/RHIKOnp1ffHwYg6tzVfT8kb/3FD0EaJfIGnnJvBrlM3z7j8
pKoLs1DSMc4KiYRLi+FzPFiZJNRGw9Tz9pUbaHQeSKtm8fdKucVov/ZcMuod
jpNqKCng+hiFat5HDRwqvO+phf9nT8VR
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 4],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsog3EABfANK5LbKG2SqLlnbHtAU/srDyIyeUBhG0qJz5AoSUkuabXk
HqY8TLblEnLbLMoDGklJY30u5a9YyyWenO/h9KtTp068tlXdwOfxeHLk3G61
HEooCXLJpKpESqaN3Wd70HV5UmqHe9nF8yx0NEdpc5MoGWYdTbUwvVe/WA+r
R7+cjdBMhrI34eux1uCB0nHTPQtjC+PGHuHGVET8QDIlATFblTYoU/Zd38Lc
dY1BkELJzIN4mVOkDPUZ4W7eV8s4VAxKBFboPfSpt2FFgl6SmUrJ3EpyoBy+
fD7zq+BAntvNT6Mkmn9g84Mlv11rAVDZr/5TQ/33pKkog5J9UsY4s9CP3Cre
oJ9RFfEBc8r9f0QySnp6mf5YGKazL+YzlLxHP22K2iiRLwtVC7PYdWqXOFef
C3XBc5R0TPACw+GKOXRBCKsTxVWRMOWi3XIHDVtHWTXz+Hut2uG03riuOBmb
7bQWZhb4ezjFZUJvHQxhPT0a+A9npcVv
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"Dethh", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`Dethh[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EABfDNpUiNjZpNS9TcYzYPaKt9yoOITB5MGRtKiRkSJa0kl7Ra
cs+t9rDFFtbIZWNRHtBISnJpLuVTSEY8Of+H069OnToJ2lZVA5vFYsmQE499
xS2mJNwnzVImUTJl7j7ehr6zwzIP3M4tmfPDveYYbX4yJUP+vSYNzOg1LNTD
6pGAtxFayWCuE74caE33MGts8dYPRUXxow9wfZKb0J9CSUicq8oBpfK+iyuY
v1ZnCk2lZPpOaGEUyDmfZrilCLSMwZwBcagdfrg/VRuwMtEglqRRMmtLCZPB
568nthr2K25u2OmU8Nm7jiBY+tu1GgLlRtWfChq+JxaLMynZIeV6bzb64auc
VxhkVnLfYV5F8I9ASklPr94ogpE6z0KBnpI3/qNT0EaJzMJTzs9g16ldYlx+
KtJFzFLSMc4Ki4I2K2eeB6uThOpomHravnINTa797Jo5/L1QbjLaL33njHqH
40gDJYXB94zCct5HLRyN9ffUwX9mK8Un
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"extrinsic curvature tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ExtrinsicKhh", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Associated to vector u\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "extrinsic curvature tensor ", 
   $CellContext`ExtrinsicKhh[$CellContext`a, $CellContext`b], ". ", 
   "Associated to vector u"],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsog3EABfBvZjUpbJQ2LVFzD7s8sKb2Vx5E5JMHlMtcSokZkpWkllzS
ask9Q3kgtlxCLtuI8oBGUktYcyl/heQST873cPrVqVMnRt/M1vEYhlEhpy77
slNOSZBHmaaLo2Tc2nmyAz3nR4UuuJORP+2H7sYIvSaekn6/u6ESpnQZZ2ph
+eDXQT1cIH0Z6/D5UG/xwbTh2Vs/lOVGD93DtTFRjDmBksCojVIHVGq7L71Q
s1ptESRSMnEnneeUaEM+rHA766tpGKp75QI7fHd+sJuwJNYoT0+iZGoxQaiC
T5+PvDJozrq54SVTEsnbcwTAgt+OlUCo7WH/WGj8Hp3NS6VklxQZDhToB7zq
Fxhg1YneYGYx/0eipMTUZeiRwdAa10y2gZLXyId1SQslqnmxzjaJXbt+jnPp
MbcmeIqSthFGGAYXF0JsYlgeJy0Lh4lnrcvX0LKxr6iYxt9L3Ran/cpzwWlw
OI4rYXoO38cpLRK/V0Gnwm+qhv9oYsVx
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"acceleration vector \"\>", "\[InvisibleSpace]", 
   RowBox[{"Accelerationu", "[", "a", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Associated to vector u\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "acceleration vector ", 
   $CellContext`Accelerationu[$CellContext`a], ". ", "Associated to vector u"],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlsog3EABfBvTJFyGaVNEjX3zC4Po632Vx5EZPJgymVDKTFDoiQluaTV
knuY8kDsy6WR2xDlAY2klsbaUP4KLZd4cr6H069OnToJ+mZtHY9hGDly4bCt
HogpCXHKJJokSiYtnee70Hl1WuyAu8rCWS88bIzW5yRTMug9bKiCGd2m+VpY
Mfx1XA+XyIByE76c6M0eKBm13nthXH78iA9uTEQm9KVQwo+1l7NQpuq5ccGc
9RpzUColUw+iRU6hKsxvgTvqr6ZRqOgXB9ngx4FfuwXLEk3irDRKZpZTguXw
+fOJp4N9arebl05JDG+fDYBFvx1rfKjq1f5poel73FqQSckeKTEeS9EPuRSv
MMCiiXyH2aWBP0IZJV3dxt44GG5wzOcaKXmLedwUtlAiXxRo5qaxa9cvcK48
5RtCZyhpG2OCI+DyUticAFYkiXRRMPWydfUOmu1H0spZ/L3RbHPabp3XnEaW
PauCWXmBHk5RieCjGipNvq4a+A9l/8Ut
  "]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefInertHead", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"projector inert-head \"\>", "\[InvisibleSpace]", 
   "Projectorhh", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefInertHead, ": Defining ", 
   "projector inert-head ", $CellContext`Projectorhh, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzlkow3EAB/ANK1KOUdokUZszdj2gqf2Uh0Vk8oByzFFKzJAoSUmOtFpy
rjG1B7ItrJFriPKARkstYc1Rfoq13E++/4dvn/rWt75J6nZVE5vFYkmRc6fV
si+gJMwlyVYIKZnV957tQNflSakT7uQUG33woDVWnZdCyajvoKUWZvZrFxth
9fjnUTNcJiM5dvhyrNZ5Yfak6c4HE5SJEw9wYyY6aSiVkpB4R6UNSuQDbg/M
W6/XcdIombvnmxl58oiAHm7nf7ZNQtmwgGOF/v2AahNWJGsFonRKDCupoVL4
/PHEroJD+be37AxK4th7tiBY8tuzFgLlg6o/FdR+TZuKsijZJWWaIzH6MY/s
FQbpFdHvMLc8+JsnoaSvXzOYACMbnIsFGkre4h7tvA5KpGauYmEeu271EuPq
k7Ih3EBJ1xQrNAquLEcscGG1kF8VA9MuOi03UOc4FNcY8det2GK0XruuGDU2
22ktFBUGexn5ZVx/HfyZeuirh/9s+8YR
  "]]
}, Open  ]],

Cell["\<\
The projection operator is $hh_{a}^{b} = \[Delta]_{a}^{b} + u_{a} u^{b} $. We \
now define a rule which allows us to replace the projector symbol with the \
actual projection operator:\
\>", "Text",
 CellChangeTimes->{{3.5714880249409237`*^9, 3.5714881412010183`*^9}, {
   3.5714881808669767`*^9, 3.571488191594795*^9}, 3.5726948004573927`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleProj", "=", 
   RowBox[{"Projectorhh", "\[Rule]", 
    RowBox[{"ProjectWith", "[", "hh", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.509359767426683*^9, 3.509359783682724*^9}, {
  3.548517642229456*^9, 3.548517647335449*^9}, {3.5726948033086*^9, 
  3.57269480391651*^9}}],

Cell["\<\
We next introduce the lapse function \[Alpha] and give a prescription how to \
substitute the acceleration vector with the lapse
a_{i} = \\frac{1}{\[Alpha]} D_{i} \[Alpha]\
\>", "Text",
 CellChangeTimes->{{3.571488199574089*^9, 3.571488297183325*^9}, {
  3.572696963860304*^9, 3.572696964614534*^9}}],

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[Alpha]", "[", "]"}], ",", "M"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Accelerationu", "/:", 
  RowBox[{"Accelerationu", "[", "a_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"cd", "[", "a", "]"}], "[", 
    RowBox[{"\[Alpha]", "[", "]"}], "]"}], "/", 
   RowBox[{"\[Alpha]", "[", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Accelerationu", "/:", 
  RowBox[{"Accelerationu", "[", 
   RowBox[{"-", "a_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"cd", "[", 
     RowBox[{"-", "a"}], "]"}], "[", 
    RowBox[{"\[Alpha]", "[", "]"}], "]"}], "/", 
   RowBox[{"\[Alpha]", "[", "]"}]}]}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.50754585464842*^9, {3.508756606866703*^9, 3.508756609348454*^9}, {
   3.508839190102326*^9, 3.508839226566879*^9}, {3.509359578969647*^9, 
   3.509359581603218*^9}, {3.509359790605136*^9, 3.509359824922992*^9}, {
   3.511460731327965*^9, 3.511460731986973*^9}, {3.5712517343631563`*^9, 
   3.571251734677559*^9}, {3.5714880075598297`*^9, 3.571488007935236*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Alpha]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Alpha][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->CompressedData["
1:eJwVzWkow3EAxvFtrrHkfkFJezF3c8xSkvwceTGiSTnKsZCkkJCr/iLHC1by
QmjM8cJoQ1tuWzZCEvN/42aK+inEC4UXnv+Lp8+rp69YVa+s4vN4PBlmzxjU
70ooEcfdxKSGUuJ+e3OyBZ9D0vPM0MoYNA647TaiSgqjRPHl1FkGGU2UthIu
ReRaq6H8LzvZCKNDjOoHKPHn3zugxdQz9AR/PNvFveGUPKpciw2QlS+wl7C3
aVPtEoFfYvM8528f8zkCJ5ih+lE4usO46GFCQEr+GlxV2iSxkZQkX7ULZXDu
QioohsuKzDt+FCVj9jeDAOoLdCvOkD3s+lFCo/lIq5BSki44aNiLo8T23iJ/
hY6cY593aPK4+g6MR1+72B0MB/q9ZtIaKAllC0yBjZRMi1rJ1AQlZ68vM5x/
d6JK0SQlOt2w0BtmnM/u+0KZsK7ED64WthmuYZBWF1+qoeTEq2eDs6Om9oKT
Pcg6KoPrzKmDc9yy9lEOs9VFHRXwH3IzzNI=
  "]],

Cell[CellGroupData[{

Cell["misc rules", "Subsubsection",
 CellChangeTimes->{{3.571482315091468*^9, 3.571482317149543*^9}}],

Cell[BoxData[{
 RowBox[{"cd", "/:", 
  RowBox[{
   RowBox[{"hh", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cd", "[", 
      RowBox[{"-", "a_"}], "]"}], "[", 
     RowBox[{
      RowBox[{"cd", "[", 
       RowBox[{"-", "b_"}], "]"}], "[", "X_", "]"}], "]"}], ")"}]}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"cd", "[", "a", "]"}], "[", 
    RowBox[{
     RowBox[{"cd", "[", 
      RowBox[{"-", "a"}], "]"}], "[", "X", "]"}], "]"}], ")"}]}], "\n", 
 RowBox[{"cd", "/:", 
  RowBox[{
   RowBox[{"hh", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cd", "[", 
      RowBox[{"-", "b_"}], "]"}], "[", "X_", "]"}], ")"}]}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"cd", "[", "a", "]"}], "[", "X", "]"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.571482172864266*^9, 3.571482180125819*^9}, {
  3.5714822216048517`*^9, 3.571482258173173*^9}, {3.5714823030235243`*^9, 
  3.571482309022563*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Decomposition of the scalar field equation of motion\
\>", "Section",
 CellChangeTimes->{{3.572692491630105*^9, 3.57269249526158*^9}, {
  3.572692545983931*^9, 3.572692559382114*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"K\[Lambda]", "[", "]"}], ",", "M"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp1\[ScriptCapitalS]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp2\[ScriptCapitalS]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"D\[ScriptCapitalS]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[ScriptCapitalS]", "[", "]"}], ",", "M"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5726925629885674`*^9, 3.572692599856881*^9}, {
  3.57269433560258*^9, 3.572694344951716*^9}, {3.57269452646448*^9, 
  3.572694527962535*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Lambda]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Lambda][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.572698087182054*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"K\[Lambda]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`K\[Lambda][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.572698087200487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp1\[ScriptCapitalS]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp1\[ScriptCapitalS][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.572698087202907*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp2\[ScriptCapitalS]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp2\[ScriptCapitalS][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.572698087204876*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"D\[ScriptCapitalS]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`D\[ScriptCapitalS][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.572698087206653*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalS]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalS][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572696968976165*^9, 3.5726980872084017`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The momentum of the scalar field is defined as K\[Lambda]=-1/(2\[Alpha]) \
(\\p_t - \[ScriptCapitalL]_{\[Beta]}) \[Lambda] = -1/2 \[ScriptCapitalL]_n \
\[Lambda]. Therefore we always subsitute  \[ScriptCapitalL]_n \[Lambda] = -2 \
K\[Lambda]\
\>", "Text",
 CellChangeTimes->{{3.572694831456903*^9, 3.572694957893003*^9}}],

Cell[BoxData[
 RowBox[{"\[Lambda]", "/:", 
  RowBox[{
   RowBox[{"LieD", "[", 
    RowBox[{"u", "[", "c_", "]"}], "]"}], "[", 
   RowBox[{"\[Lambda]", "[", "]"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "2"}], 
   RowBox[{"K\[Lambda]", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.572692655538986*^9, 3.572692695622328*^9}, {
  3.5726980927497387`*^9, 3.572698092927105*^9}}],

Cell["\<\
Here, we define the equation of motion for the scalar field.\
\>", "Text",
 CellChangeTimes->{{3.572694965056828*^9, 3.5726949785772467`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalS]", "[", "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"gg", "[", 
       RowBox[{"a", ",", "b"}], "]"}], 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "a"}], "]"}], "[", 
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "b"}], "]"}], "[", 
        RowBox[{"\[Lambda]", "[", "]"}], "]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Dim", "-", "6"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], " ", 
      RowBox[{"gg", "[", 
       RowBox[{"a", ",", "b"}], "]"}], 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "a"}], "]"}], "[", 
       RowBox[{"\[Lambda]", "[", "]"}], "]"}], 
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "b"}], "]"}], "[", 
       RowBox[{"\[Lambda]", "[", "]"}], "]"}]}], "-", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"Dim", "-", "5"}], ")"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5726927015127497`*^9, 3.5726927193998737`*^9}, {
  3.572692766816753*^9, 3.572692826923387*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "5"}], "+", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "6"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"g", 
         StyleBox[GridBox[{
            {"a", "b"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`gg[$CellContext`a, $CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {"a", "b"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`gg[$CellContext`a, $CellContext`b],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[EmptyDownTriangle]", "b"], 
       SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`b][
      $CellContext`CD[-$CellContext`a][
       $CellContext`\[Lambda][]]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5726927130987473`*^9, 3.572692716791565*^9}, {
   3.5726928118128223`*^9, 3.572692827699092*^9}, 3.572694608623581*^9, 
   3.57269505747626*^9, 3.572696972291115*^9, 3.572698094901496*^9}]
}, Open  ]],

Cell["\<\
In the following we decompose the scalar field equation of motion \
\[ScriptCapitalS] and rewrite every 4-dimensional quantity with the \
corresponding 3-dimensional expressions.\
\>", "Text",
 CellChangeTimes->{{3.572694983056568*^9, 3.572695045134749*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp1\[ScriptCapitalS]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"InducedDecomposition", "[", 
      RowBox[{
       RowBox[{"\[ScriptCapitalS]", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"hh", ",", "u"}], "}"}]}], "]"}], "/.", "ruleProj"}], "//", 
    "NoScalar"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572692830849531*^9, 3.5726928706636333`*^9}, 
   3.572694333126987*^9, {3.572695049945261*^9, 3.572695067414154*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False]}], ")"}], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], 
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`CD[-$CellContext`a][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], 
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`CD[-$CellContext`a][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.572692844544491*^9, 3.572692872752139*^9}, 
   3.5726943515083942`*^9, {3.5726946098649693`*^9, 3.57269462783947*^9}, {
   3.5726950503681707`*^9, 3.5726950680144587`*^9}, 3.572696974331203*^9, 
   3.5726980966593857`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp2\[ScriptCapitalS]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToInducedDerivative", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToInducedDerivative", "[", 
         RowBox[{
          RowBox[{"tmp1\[ScriptCapitalS]", "[", "]"}], ",", "CD", ",", "cd"}],
          "]"}], "//", "GradNormalToExtrinsicK"}], "//", "Simplification"}], 
      ",", "CD", ",", "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572692874033082*^9, 3.572692906395103*^9}, {
  3.5726943224990053`*^9, 3.5726944235126*^9}}],

Cell[BoxData[
 RowBox[{"10", "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox["Dim",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Dim,
    Editable->False]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"a", " "},
           {" ", "a"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox["K\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`K\[Lambda][],
    Editable->False]}], "+", 
  FractionBox[
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "a"], 
     SuperscriptBox["D", "a"], "\[Lambda]"}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`a][
    $CellContext`cd[$CellContext`a][
     $CellContext`\[Lambda][]]],
   Editable->False], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Alpha]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Alpha][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Alpha]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Alpha][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`u[$CellContext`a]][
      $CellContext`K\[Lambda][]],
     Editable->False], ")"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"u", 
        StyleBox[GridBox[{
           {"a"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`u[$CellContext`a],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", "u"], 
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`u[$CellContext`a]][
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.572692884334161*^9, 3.5726929076698523`*^9}, {
   3.572694326897571*^9, 3.5726943609183817`*^9}, 3.572694424011035*^9, {
   3.572694611523789*^9, 3.5726946287051153`*^9}, 3.572695069767131*^9, 
   3.572696976369783*^9, 3.572698098413971*^9}]
}, Open  ]],

Cell["\<\
We impose the Leibniz rule to re-express the last term in tmp2\
\[ScriptCapitalS]\
\>", "Text",
 CellChangeTimes->{{3.572695082292193*^9, 3.572695103197003*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule\[Lambda]", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "a_", "]"}], 
     RowBox[{
      RowBox[{"LieD", "[", 
       RowBox[{"u", "[", "c_", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"cd", "[", 
        RowBox[{"-", "a_"}], "]"}], "[", 
       RowBox[{"\[Lambda]", "[", "]"}], "]"}], "]"}]}], "\[RuleDelayed]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "b", "}"}], ",", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"cd", "[", 
          RowBox[{"-", "b"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}]}], 
       RowBox[{
        RowBox[{"LieD", "[", 
         RowBox[{"u", "[", "c", "]"}], "]"}], "[", 
        RowBox[{"u", "[", "b", "]"}], "]"}]}]}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.57269443640924*^9, 3.572694486089938*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["a", "_"]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[
      Pattern[$CellContext`a, 
       Blank[]]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[ScriptCapitalL]", "u"], 
        RowBox[{
         SubscriptBox["D", 
          UnderscriptBox["a", "_"]], "\[Lambda]"}]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`LieD[
       $CellContext`u[
        Pattern[$CellContext`c, 
         Blank[]]]][
       $CellContext`cd[-Pattern[$CellContext`a, 
          Blank[]]][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], "\[RuleDelayed]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "b", "}"}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "b"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[ScriptCapitalL]", "u"], GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"b"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`LieD[
         $CellContext`u[$CellContext`c]][
         $CellContext`u[$CellContext`b]],
        Editable->False], ")"}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.572694486752419*^9, {3.572694618498055*^9, 3.572694629906066*^9}, 
   3.572695106503825*^9, 3.572696978040901*^9, 3.57269810062324*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D\[ScriptCapitalS]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{"tmp2\[ScriptCapitalS]", "[", "]"}], "/.", 
   "rule\[Lambda]"}]}]], "Input",
 CellChangeTimes->{{3.5726944898870697`*^9, 3.5726945176376534`*^9}}],

Cell[BoxData[
 RowBox[{"10", "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox["Dim",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Dim,
    Editable->False]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"a", " "},
           {" ", "a"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox["K\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`K\[Lambda][],
    Editable->False]}], "+", 
  FractionBox[
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "a"], 
     SuperscriptBox["D", "a"], "\[Lambda]"}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`a][
    $CellContext`cd[$CellContext`a][
     $CellContext`\[Lambda][]]],
   Editable->False], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Alpha]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Alpha][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Alpha]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Alpha][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`u[$CellContext`a]][
      $CellContext`K\[Lambda][]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.572694500103869*^9, 3.572694518422596*^9}, {
   3.5726946192141123`*^9, 3.57269463064489*^9}, 3.572695107647717*^9, 
   3.572696979725466*^9, 3.572698102174279*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["explicit time evolution", "Subsection",
 CellChangeTimes->{{3.571491994888405*^9, 3.571492003047883*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s perform a last change of variables to bring the time \
evolution equation in an explicit form. Therefore, remember that the time \
parameter $t$ is related to the lapse function \[Alpha] and shift vector \
\[Beta]^i :
t^a = \[Alpha] u^a + \[Beta]^a
Then the Lie derivative along u^a is given by 
\[ScriptCapitalL]_u = 1/\[Alpha] (\\partial_t - \[ScriptCapitalL]_\[Beta] )\
\>", "Text",
 CellChangeTimes->{{3.571492023630519*^9, 3.571492193945265*^9}, {
   3.571492413890341*^9, 3.571492414392048*^9}, 3.5726951151624813`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefParameter", "[", "t", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[Beta]i", "[", "a", "]"}], ",", "M", ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"u", "[", 
      RowBox[{"-", "a"}], "]"}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"hh", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", "b"}], "]"}], "}"}]}]}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefParameter", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parameter \"\>", "\[InvisibleSpace]", "t", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefParameter, ": Defining ", 
   "parameter ", $CellContext`t, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571899854357095*^9, 3.5726913981920357`*^9, 
  3.57269467303924*^9, 3.572695121584153*^9, 3.57269698268402*^9, 
  3.572698104921266*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Beta]i", "[", "a", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Beta]i[$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571899854357095*^9, 3.5726913981920357`*^9, 
  3.57269467303924*^9, 3.572695121584153*^9, 3.57269698268402*^9, 
  3.572698104939508*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ruleLieu", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"LieD", "[", 
     RowBox[{"u", "[", "c_", "]"}], "]"}], "[", "X_", "]"}], "\[RuleDelayed]", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"\[Alpha]", "[", "]"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"LieD", "[", "t", "]"}], "[", "X", "]"}], "-", 
      RowBox[{
       RowBox[{"LieD", "[", 
        RowBox[{"\[Beta]i", "[", "c", "]"}], "]"}], "[", "X", "]"}]}], 
     ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", "u"], "X_"}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`u[
     Pattern[$CellContext`c, 
      Blank[]]]][
    Pattern[$CellContext`X, 
     Blank[]]],
   Editable->False], "\[RuleDelayed]", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", 
        TagBox[
         InterpretationBox[
          StyleBox["t",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`t,
          Editable->False],
         Short]], "X"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[$CellContext`t][$CellContext`X],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox["\[ScriptCapitalL]", "\[Beta]i"], "X"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`LieD[
      $CellContext`\[Beta]i[$CellContext`c]][$CellContext`X],
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Alpha]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Alpha][],
    Editable->False]]}]], "Output",
 CellChangeTimes->{3.5718998577021112`*^9, 3.572691399697658*^9, 
  3.572694675378353*^9, 3.572695123117178*^9, 3.572696984172927*^9, 
  3.572698106211217*^9}]
}, Open  ]],

Cell["\<\
We now impose this rule on the decomposed EoM for the scalar field and solve \
for $\\partial_t K\[Lambda]$.\
\>", "Text",
 CellChangeTimes->{{3.57149241022152*^9, 3.5714924537232933`*^9}, {
  3.572695130739876*^9, 3.5726951521165257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"dtK\[Lambda]", "[", "]"}], ",", "M"}], "]"}]], "Input",
 CellChangeTimes->{{3.571492275886189*^9, 3.571492300853351*^9}, {
  3.572694678719676*^9, 3.572694687928062*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"dtK\[Lambda]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`dtK\[Lambda][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571492302049062*^9, 3.5718998606123543`*^9, 
  3.572691400965912*^9, 3.5726946887753277`*^9, 3.572695155537128*^9, 
  3.572696985714184*^9, 3.572698107878031*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ruledtK\[Lambda]", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D\[ScriptCapitalS]", "[", "]"}], "/.", "ruleLieu"}], ")"}], 
      "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"LieD", "[", "t", "]"}], "[", 
      RowBox[{"K\[Lambda]", "[", "]"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5714922340661707`*^9, 3.57149225657306*^9}, {
  3.571492306533511*^9, 3.571492321294832*^9}, {3.571492353624301*^9, 
  3.571492360774292*^9}, {3.5726946914660597`*^9, 3.572694715124198*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", 
      TagBox[
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t,
        Editable->False],
       Short]], "K\[Lambda]"}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[$CellContext`t][
    $CellContext`K\[Lambda][]],
   Editable->False], "\[Rule]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "24"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`K\[Lambda][],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["K\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`K\[Lambda][],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False]}], "-", 
     RowBox[{"20", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {"a", " "},
              {" ", "a"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], 
          SuperscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`cd[$CellContext`a][
          $CellContext`\[Lambda][]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["D", "a"], "\[Alpha]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`a][
         $CellContext`\[Alpha][]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"6", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[ScriptCapitalL]", "\[Beta]i"], "K\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`LieD[
         $CellContext`\[Beta]i[$CellContext`a]][
         $CellContext`K\[Lambda][]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.571492257129302*^9, {3.571492308875369*^9, 3.571492321842141*^9}, 
   3.571899865518251*^9, 3.572691403836198*^9, 3.572694716261466*^9, 
   3.572695156831332*^9, 3.57269698714921*^9, 3.572698108753242*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dtK\[Lambda]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"LieD", "[", "t", "]"}], "[", 
    RowBox[{"K\[Lambda]", "[", "]"}], "]"}], "/.", 
   "ruledtK\[Lambda]"}]}]], "Input",
 CellChangeTimes->{{3.571492324509399*^9, 3.571492374961005*^9}, {
  3.571492471139482*^9, 3.571492474416257*^9}, {3.572694723661813*^9, 
  3.572694743369894*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "24"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False]}], "-", 
    RowBox[{"20", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"a", " "},
             {" ", "a"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], 
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`cd[$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Alpha]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Alpha][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "\[Beta]i"], "K\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`\[Beta]i[$CellContext`a]][
        $CellContext`K\[Lambda][]],
       Editable->False], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.571899866836966*^9, 3.5726914046943283`*^9, {3.572694718755348*^9, 
   3.572694743745687*^9}, 3.572695157749021*^9, 3.572696990299382*^9, 
   3.572698110383996*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(D-1)+1 Decomposition of Einstein's equations\
\>", "Section",
 CellChangeTimes->{
  3.509359569912281*^9, 3.509359700114093*^9, {3.510048140796031*^9, 
   3.510048142984953*^9}, {3.548517711606202*^9, 3.54851771232722*^9}, {
   3.571488336278193*^9, 3.571488339546661*^9}}],

Cell["\<\
In the following section we perform the (D-1)+1 split of Einstein\
\[CloseCurlyQuote]s equations and will derive the constraint and evolution \
equations.\
\>", "Text",
 CellChangeTimes->{{3.571488385749961*^9, 3.571488433688002*^9}}],

Cell[CellGroupData[{

Cell["\<\
Define the energy momentum tensor (version 1)\
\>", "Subsection",
 CellChangeTimes->{{3.572695169356462*^9, 3.572695174401616*^9}, {
  3.572696149547515*^9, 3.572696154437532*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"TT", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"DTT", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.572695394900236*^9, 3.572695406555195*^9}, {
   3.572696191520507*^9, 3.5726962015068893`*^9}, 3.572696384201969*^9, {
   3.5726965302601852`*^9, 3.572696531045136*^9}, {3.57269700478008*^9, 
   3.5726970049706583`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"TT", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`TT[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5726951838376017`*^9, 3.572695401762184*^9, 
  3.572696993787916*^9, 3.5726981136745033`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"DTT", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`DTT[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5726951838376017`*^9, 3.572695401762184*^9, 
  3.572696993787916*^9, 3.572698113706264*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
The energy-momentum tensor for the scalar field is given by\
\>", "Text",
 CellChangeTimes->{{3.572695273939687*^9, 3.572695284997217*^9}, {
  3.572695432269006*^9, 3.572695432516758*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TT", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Dim", "-", "4"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"16", " ", "\[Pi]", " ", 
        RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"CD", "[", 
         RowBox[{"-", "a"}], "]"}], "[", 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "b"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}], "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", 
           RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "a"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "b"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Dim", "-", "5"}], ")"}], 
        RowBox[{"gg", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}]}], " ", "+", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Dim", "-", "5"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", 
           RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], " ", 
        RowBox[{"gg", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], 
        RowBox[{"gg", "[", 
         RowBox[{"c", ",", "d"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "c"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}], 
        RowBox[{
         RowBox[{"CD", "[", 
          RowBox[{"-", "d"}], "]"}], "[", 
         RowBox[{"\[Lambda]", "[", "]"}], "]"}]}]}], ")"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.572695286202648*^9, 3.572695387890864*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}]}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"g", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`gg[-$CellContext`a, -$CellContext`b],
       Editable->False]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}]], "+", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "b"], 
        SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]]],
      Editable->False], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`gg[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {"c", "d"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`gg[$CellContext`c, $CellContext`d],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`c][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`d][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}]]}], ")"}]}], 
  RowBox[{"16", " ", "\[Pi]", " ", 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]}]]], "Output",
 CellChangeTimes->{{3.572695378302018*^9, 3.572695388383409*^9}, 
   3.572696995344061*^9, 3.572698115567292*^9}]
}, Open  ]],

Cell["\<\
We now perform the 3+1 decomposition of the energy-momentum tensor\
\>", "Text",
 CellChangeTimes->{{3.572695412031867*^9, 3.5726954298447323`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DTT", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"InducedDecomposition", "[", 
      RowBox[{
       RowBox[{"TT", "[", 
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{"-", "b"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"hh", ",", "u"}], "}"}]}], "]"}], "/.", "ruleProj"}], "//", 
    "NoScalar"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572695434842321*^9, 3.572695477206912*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "\[Pi]", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hh[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda][],
           Editable->False]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {"c", "d"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[$CellContext`c, $CellContext`d],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"c"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`c],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"d"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`d],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {" ", "c"},
                  {"a", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[-$CellContext`a, $CellContext`c],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {" ", "d"},
                  {"b", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[-$CellContext`b, $CellContext`d],
           Editable->False]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {" ", "d"},
                  {"a", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[-$CellContext`a, $CellContext`d],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {" "},
                  {"b"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[-$CellContext`b],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"c"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`c],
           Editable->False]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda][],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], 
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]]],
            Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"a"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`a],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {" ", "d"},
                  {"b", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[-$CellContext`b, $CellContext`d],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"c"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`c],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`c][
                $CellContext`\[Lambda][]],
               Editable->False], ")"}], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`d][
                $CellContext`\[Lambda][]],
               Editable->False], ")"}]}], "-", 
            RowBox[{"2", " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda][],
              Editable->False], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[EmptyDownTriangle]", "d"], 
                 SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`d][
                $CellContext`CD[-$CellContext`c][
                 $CellContext`\[Lambda][]]],
               Editable->False], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {" "},
                  {"b"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[-$CellContext`b],
           Editable->False], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               InterpretationBox[
                StyleBox["Dim",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Dim,
                Editable->False]}], ")"}], " ", 
             InterpretationBox[
              StyleBox["\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Lambda][],
              Editable->False]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", 
               InterpretationBox[
                StyleBox["Dim",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Dim,
                Editable->False]}], ")"}], " ", 
             InterpretationBox[
              StyleBox[GridBox[{
                 {"h", 
                  StyleBox[GridBox[{
                    {"c", "d"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`hh[$CellContext`c, $CellContext`d],
              Editable->False], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`c][
                $CellContext`\[Lambda][]],
               Editable->False], ")"}], " ", 
             RowBox[{"(", 
              InterpretationBox[
               StyleBox[
                RowBox[{
                 SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`CD[-$CellContext`d][
                $CellContext`\[Lambda][]],
               Editable->False], ")"}]}], "-", 
            RowBox[{
             InterpretationBox[
              StyleBox[GridBox[{
                 {"u", 
                  StyleBox[GridBox[{
                    {"c"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`u[$CellContext`c],
              Editable->False], " ", 
             InterpretationBox[
              StyleBox[GridBox[{
                 {"u", 
                  StyleBox[GridBox[{
                    {"d"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`u[$CellContext`d],
              Editable->False], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "7"}], "+", 
                  InterpretationBox[
                   StyleBox["Dim",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`Dim,
                   Editable->False]}], ")"}], " ", 
                RowBox[{"(", 
                 InterpretationBox[
                  StyleBox[
                   RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`CD[-$CellContext`c][
                   $CellContext`\[Lambda][]],
                  Editable->False], ")"}], " ", 
                RowBox[{"(", 
                 InterpretationBox[
                  StyleBox[
                   RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`CD[-$CellContext`d][
                   $CellContext`\[Lambda][]],
                  Editable->False], ")"}]}], "+", 
               RowBox[{"4", " ", 
                InterpretationBox[
                 StyleBox["\[Lambda]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Lambda][],
                 Editable->False], " ", 
                RowBox[{"(", 
                 InterpretationBox[
                  StyleBox[
                   RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], 
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`CD[-$CellContext`d][
                   $CellContext`CD[-$CellContext`c][
                    $CellContext`\[Lambda][]]],
                  Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.572695445036871*^9, 3.572695479140255*^9}, 
   3.572696999655367*^9, 3.572698120111546*^9}]
}, Open  ]],

Cell["\<\
In the following we compute the energy density, current and spatial part of \
the energy-momentum tensor. They are related to the various projection as 
(a) energy density:             \[Rho] = T_{ab} u^{a} u^{b}
(b) energy current:            j_i = -T_{ab} u^a h^{b}_{i}
(c) spatial components:  S_{ij} = h^a_i h^b_j T_{ab}\
\>", "Text",
 CellChangeTimes->{{3.572695488663216*^9, 3.572695543886292*^9}}],

Cell[CellGroupData[{

Cell["energy density", "Subsubsection",
 CellChangeTimes->{{3.572695546286379*^9, 3.572695549454957*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp1\[Rho]", "[", "]"}], ",", "M"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"\[Rho]", "[", "]"}], ",", "M"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.572695644176405*^9, 3.572695659894085*^9}, {
  3.57269619492902*^9, 3.572696195311349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp1\[Rho]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp1\[Rho][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5726956607728252`*^9, 3.5726970083521557`*^9, 
  3.5726981226016006`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Rho]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Rho][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.5726956607728252`*^9, 3.5726970083521557`*^9, 
  3.5726981226339197`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp1\[Rho]", "[", "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"ToInducedDerivative", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ToInducedDerivative", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"DTT", "[", 
               RowBox[{
                RowBox[{"-", "a"}], ",", 
                RowBox[{"-", "b"}]}], "]"}], 
              RowBox[{"u", "[", "a", "]"}], 
              RowBox[{"u", "[", "b", "]"}]}], "//", "Simplification"}], ",", 
            "CD", ",", "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
         "Simplification"}], ",", "CD", ",", "cd"}], "]"}], "//", 
      "GradNormalToExtrinsicK"}], "//", "Simplification"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.572695555372044*^9, 3.5726956317459497`*^9}, {
  3.5726956619375057`*^9, 3.5726956778851767`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"64", " ", "\[Pi]", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["D", "a"], "\[Alpha]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`a][
            $CellContext`\[Alpha][]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           InterpretationBox[
            StyleBox["Dim",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Dim,
            Editable->False]}], ")"}], " ", 
         InterpretationBox[
          StyleBox["\[Alpha]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Alpha][],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox["D", "a"], "\[Lambda]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`a][
            $CellContext`\[Lambda][]],
           Editable->False], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "7"}], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["K\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`K\[Lambda][],
           Editable->False], "2"]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["K\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`K\[Lambda][],
           Editable->False], "2"]}], "-", 
        RowBox[{"5", " ", 
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False]}], "-", 
        RowBox[{"2", " ", 
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`LieD[
            $CellContext`u[$CellContext`a]][
            $CellContext`K\[Lambda][]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {"u", 
              StyleBox[GridBox[{
                 {"a"},
                 {" "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->9]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`u[$CellContext`a],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SubscriptBox["\[ScriptCapitalL]", "u"], 
             RowBox[{
              SubscriptBox["D", "a"], "\[Lambda]"}]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xTensor`LieD[
            $CellContext`u[$CellContext`a]][
            $CellContext`cd[-$CellContext`a][
             $CellContext`\[Lambda][]]],
           Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5726955629523*^9, 3.572695632355385*^9}, 
   3.572695678357407*^9, 3.572697009358444*^9, 3.572698123757888*^9}]
}, Open  ]],

Cell["\<\
Again, we need to re-express the last term in the expression. In order to \
substitute \[ScriptCapitalL]_u K\[Lambda] we add the appropriate amount of D\
\[ScriptCapitalS]=0\
\>", "Text",
 CellChangeTimes->{{3.5726956833566713`*^9, 3.5726956996975594`*^9}, {
   3.572695736964961*^9, 3.5726957653013268`*^9}, 3.572698130269936*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tmp1\[Rho]", "[", "]"}], "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Dim", "-", "4"}], ")"}], 
      RowBox[{
       RowBox[{"D\[ScriptCapitalS]", "[", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"16", " ", "\[Pi]", " ", 
         RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}]}]}], "/.", 
    "rule\[Lambda]"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572695701123934*^9, 3.572695709662312*^9}, {
  3.572695771347872*^9, 3.572695905619239*^9}, {3.572695973406891*^9, 
  3.572696012966625*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "\[Pi]", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "20"}], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`K\[Lambda][],
         Editable->False], "2"]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox["K\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`K\[Lambda][],
         Editable->False], "2"]}], "-", 
      RowBox[{"20", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}], "+", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}], "+", 
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {"a", " "},
               {" ", "a"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["K\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`K\[Lambda][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "a"], 
           SuperscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`a][
          $CellContext`cd[$CellContext`a][
           $CellContext`\[Lambda][]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{"7", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.572695710132311*^9, {3.572695776791037*^9, 3.572695906036458*^9}, {
   3.572695983843367*^9, 3.572696014087919*^9}, 3.572697011384994*^9, 
   3.572698125856106*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["energy current", "Subsubsection",
 CellChangeTimes->{{3.572696222773793*^9, 3.572696224810319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"ji", "[", 
     RowBox[{"-", "a"}], "]"}], ",", "M", ",", 
    RowBox[{"OrthogonalTo", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"u", "[", "a", "]"}], "}"}]}], ",", 
    RowBox[{"ProjectedWith", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}]}], "]"}], "}"}]}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"tmpji", "[", 
     RowBox[{"-", "a"}], "]"}], ",", "M", ",", 
    RowBox[{"OrthogonalTo", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"u", "[", "a", "]"}], "}"}]}], ",", 
    RowBox[{"ProjectedWith", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "b"}]}], "]"}], "}"}]}]}], " ", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5726962112579536`*^9, 3.572696228058803*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ji", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ji[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572697018551628*^9, 3.572698133449321*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmpji", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmpji[-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572697018551628*^9, 3.5726981334732924`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmpji", "[", 
   RowBox[{"-", "a_"}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b", ",", "c"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"hh", "[", 
        RowBox[{
         RowBox[{"-", "a"}], ",", "b"}], "]"}]}], 
      RowBox[{"TT", "[", 
       RowBox[{
        RowBox[{"-", "b"}], ",", 
        RowBox[{"-", "c"}]}], "]"}], 
      RowBox[{"u", "[", "c", "]"}]}], "//", "Simplification"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5726963066379004`*^9, 3.572696325689678*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False]}], ")"}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"h", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`hh[-$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"u", 
        StyleBox[GridBox[{
           {"b"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`u[$CellContext`b],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`b][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[EmptyDownTriangle]", "c"], 
          SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`c][
         $CellContext`CD[-$CellContext`b][
          $CellContext`\[Lambda][]]],
        Editable->False], ")"}]}]}], ")"}]}], 
  RowBox[{"32", " ", "\[Pi]", " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]}]]], "Output",
 CellChangeTimes->{3.572696326151216*^9, 3.572697019433766*^9, 
  3.572698135346171*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ji", "[", 
   RowBox[{"-", "a_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToInducedDerivative", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToInducedDerivative", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"tmpji", "[", 
            RowBox[{"-", "a"}], "]"}], "//", "Simplification"}], ",", "CD", 
          ",", "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
       "Simplification"}], ",", "CD", ",", "cd"}], "]"}], "//", 
    "GradNormalToExtrinsicK"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572696231593789*^9, 3.572696300904346*^9}, {
  3.572696330987124*^9, 3.57269635198798*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "K\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`K\[Lambda][]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", "b"},
              {"a", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}]}], ")"}]}], 
  RowBox[{"16", " ", "\[Pi]", " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]}]]], "Output",
 CellChangeTimes->{{3.572696243168201*^9, 3.5726963014813957`*^9}, {
   3.572696334536009*^9, 3.572696353095191*^9}, 3.5726970205814247`*^9, 
   3.572698136376993*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
spatial projection of the energy momentum tensor\
\>", "Subsubsection",
 CellChangeTimes->{{3.5726963570874043`*^9, 3.5726963778590097`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"Sij", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
    RowBox[{"OrthogonalTo", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "[", "a", "]"}], ",", 
       RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
    RowBox[{"ProjectedWith", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hh", "[", 
        RowBox[{"a", ",", 
         RowBox[{"-", "c"}]}], "]"}], ",", 
       RowBox[{"hh", "[", 
        RowBox[{"b", ",", 
         RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"tmpSij", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
    RowBox[{"OrthogonalTo", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "[", "a", "]"}], ",", 
       RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
    RowBox[{"ProjectedWith", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hh", "[", 
        RowBox[{"a", ",", 
         RowBox[{"-", "c"}]}], "]"}], ",", 
       RowBox[{"hh", "[", 
        RowBox[{"b", ",", 
         RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.572696389905549*^9, 3.572696392846479*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Sij", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Sij[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572697022346674*^9, 3.572698138655294*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmpSij", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmpSij[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.572697022346674*^9, 3.5726981386800623`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmpSij", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"hh", "[", 
        RowBox[{
         RowBox[{"-", "a"}], ",", "c"}], "]"}], 
       RowBox[{"hh", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", "d"}], "]"}], 
       RowBox[{"TT", "[", 
        RowBox[{
         RowBox[{"-", "c"}], ",", 
         RowBox[{"-", "d"}]}], "]"}]}], "//", "MetricToProjector"}], "//", 
     "Simplification"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5726964019081297`*^9, 3.5726964289974337`*^9}, {
  3.572696483830027*^9, 3.572696489118387*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "\[Pi]", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}]], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hh[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda][],
           Editable->False]}], "-", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"h", 
               StyleBox[GridBox[{
                  {"c", "d"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`hh[$CellContext`c, $CellContext`d],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"c"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`c],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"u", 
               StyleBox[GridBox[{
                  {"d"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`u[$CellContext`d],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {" ", "c"},
               {"a", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hh[-$CellContext`a, $CellContext`c],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {" ", "d"},
               {"b", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hh[-$CellContext`b, $CellContext`d],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox["\[Lambda]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Lambda][],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["\[EmptyDownTriangle]", "d"], 
              SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`CD[-$CellContext`d][
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]]],
            Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.572696412755855*^9, 3.572696429542817*^9}, 
   3.572696489742152*^9, 3.572697038366302*^9, 3.5726981408800507`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sij", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToInducedDerivative", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToInducedDerivative", "[", 
         RowBox[{
          RowBox[{"tmpSij", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", 
            RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", "cd"}], "]"}], "//", 
        "GradNormalToExtrinsicK"}], "//", "Simplification"}], ",", "CD", ",", 
      "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572696436211275*^9, 3.572696475463244*^9}, {
  3.572696512679132*^9, 3.5726965174093437`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["K\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`K\[Lambda][],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "b"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`\[Lambda][]],
         Editable->False], ")"}]}], "-", 
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox["D", "b"], 
           SubscriptBox["D", "a"], "\[Lambda]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`b][
          $CellContext`cd[-$CellContext`a][
           $CellContext`\[Lambda][]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "5"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"h", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`hh[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             InterpretationBox[
              StyleBox["K\[Lambda]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`K\[Lambda][],
              Editable->False], "2"], "+", 
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox["D", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SuperscriptBox["D", "c"], "\[Lambda]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[$CellContext`c][
             $CellContext`\[Lambda][]],
            Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"64", " ", "\[Pi]", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.57269644648197*^9, 3.572696518406752*^9}, 
   3.572697040049814*^9, 3.572698143023456*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define EoMs", "Subsection",
 CellChangeTimes->{{3.571251685983912*^9, 3.5712516916615353`*^9}, {
   3.5714827225355864`*^9, 3.571482727285089*^9}, {3.5714868129664803`*^9, 
   3.5714868134082317`*^9}, 3.571489895395516*^9}],

Cell["\<\
Here we define the equations of motion denoted by  $EE_{ab}$ and the \
energy-momentum tensor $TT_{ab}$. 
Additionally we define the energy density $\[Rho]$, the current $j_{i}$ and \
the spatial part of the energy-momentum tensor $S_{ij}$.
We define the gravitational constant $G_D$ as constant symbol.\
\>", "Text",
 CellChangeTimes->{{3.571488438581098*^9, 3.571488443078177*^9}, {
   3.5714884774261503`*^9, 3.5714887474971933`*^9}, 3.571488940722579*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"EE1", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"EE2", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.571473259725028*^9, 3.571473303953519*^9}, {
   3.571480533652624*^9, 3.571480534716796*^9}, {3.571481260149445*^9, 
   3.571481285108601*^9}, 3.5714827404498167`*^9, {3.571488459056398*^9, 
   3.571488483846977*^9}, 3.5726951799566383`*^9, 3.572697045172936*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"EE1", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`EE1[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571473304399455*^9, 3.571482698189039*^9, 
  3.571489507606119*^9, 3.571899782358901*^9, 3.572691358933036*^9, 
  3.572697045721649*^9, 3.572698145375642*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"EE2", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`EE2[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571473304399455*^9, 3.571482698189039*^9, 
  3.571489507606119*^9, 3.571899782358901*^9, 3.572691358933036*^9, 
  3.572697045721649*^9, 3.572698145399428*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
We will make use of Einstein\[CloseCurlyQuote]s eqs in the following forms:
(i)  EE1_{ab}:=R_{ab} - 1/2 g_{ab} R - 8\[Pi] G_D T_{ab} = 0
(ii) EE2_{ab}:=R_{ab} - 8 \[Pi] G_D (T_{ab} - 1/2 g_{ab} T ) = 0\
\>", "Text",
 CellChangeTimes->{3.5714889487352867`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EE1", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{"RicciCD", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"1", "/", "2"}], " ", 
    RowBox[{"gg", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], " ", 
    RowBox[{"RicciScalarCD", "[", "]"}]}], "-", 
   RowBox[{"8", "\[Pi]", " ", 
    RowBox[{"TT", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE2", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}], ",", 
    RowBox[{
     RowBox[{"RicciCD", "[", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "]"}], "-", 
     RowBox[{"8", "\[Pi]", " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], "-", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", 
         RowBox[{"gg", "[", 
          RowBox[{
           RowBox[{"-", "a"}], ",", 
           RowBox[{"-", "b"}]}], "]"}], 
         RowBox[{"gg", "[", 
          RowBox[{"c", ",", "d"}], "]"}], 
         RowBox[{"TT", "[", 
          RowBox[{
           RowBox[{"-", "c"}], ",", 
           RowBox[{"-", "d"}]}], "]"}]}]}], ")"}]}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5714804850057297`*^9, 3.5714805054653463`*^9}, {
  3.571480549524234*^9, 3.571480582798174*^9}, {3.571488954449914*^9, 
  3.571488967941937*^9}, {3.5714895265011377`*^9, 3.571489543878536*^9}, {
  3.572697051875243*^9, 3.5726970561368647`*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b],
   Editable->False], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"g", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`gg[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciScalarCD[],
    Editable->False]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}]}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`gg[-$CellContext`a, -$CellContext`b],
        Editable->False]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`a][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}]], "+", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], 
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"g", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`gg[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"g", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`gg[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}]]}], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{
  3.571488968254118*^9, {3.5714895155002003`*^9, 3.571489544345572*^9}, 
   3.571490451540881*^9, 3.571899788479711*^9, 3.572691364226746*^9, 
   3.572697056822209*^9, 3.5726981478498993`*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", "\[EmptyDownTriangle]", "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciCD[-$CellContext`a, -$CellContext`b],
   Editable->False], "-", 
  RowBox[{"8", " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}]}], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"g", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"a", "b"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`gg[-$CellContext`a, -$CellContext`b],
           Editable->False]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`a][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`b][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}]], "+", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "b"], 
            SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`b][
           $CellContext`CD[-$CellContext`a][
            $CellContext`\[Lambda][]]],
          Editable->False], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"g", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"a", "b"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`gg[-$CellContext`a, -$CellContext`b],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"g", 
                StyleBox[GridBox[{
                   {"c", "e"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`gg[$CellContext`c, $CellContext`e],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "e"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`e][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}]]}], ")"}]}], 
      RowBox[{"16", " ", "\[Pi]", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False]}], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`gg[-$CellContext`a, -$CellContext`b],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"g", 
            StyleBox[GridBox[{
               {"d", "f"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`gg[$CellContext`d, $CellContext`f],
        Editable->False], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}]}], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {"g", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"d", "f"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`gg[-$CellContext`d, -$CellContext`f],
           Editable->False]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"g", 
                StyleBox[GridBox[{
                   {"c", "e"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`gg[$CellContext`c, $CellContext`e],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"g", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"d", "f"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`gg[-$CellContext`d, -$CellContext`f],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "e"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`e][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "f"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`f][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}]], "+", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "f"], 
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`f][
           $CellContext`CD[-$CellContext`d][
            $CellContext`\[Lambda][]]],
          Editable->False]}], ")"}]}], 
      RowBox[{"32", " ", "\[Pi]", " ", 
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False]}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.571488968254118*^9, {3.5714895155002003`*^9, 3.571489544345572*^9}, 
   3.571490451540881*^9, 3.571899788479711*^9, 3.572691364226746*^9, 
   3.572697056822209*^9, 3.5726981478662233`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
decomposition of Einstein\[CloseCurlyQuote]s equations\
\>", "Subsection",
 CellChangeTimes->{{3.548959684967298*^9, 3.548959691347014*^9}, {
  3.571489901602862*^9, 3.571489909703541*^9}}],

Cell["\<\
We now want to 3+1 split the Einstein\[CloseCurlyQuote]s equations. Therefore \
we introduce two additional tensor fields which will denote the decomposed \
equations of motion. Conveniently, xtensor already knows how the \
Gauss-Codazzi relations for the Riemann and Ricci tensor, which we can easily \
apply.
Note, that we will substitute the various projections of the energy momentum \
tensor as defined above.\
\>", "Text",
 CellChangeTimes->{{3.571489208712117*^9, 3.571489357698678*^9}, {
  3.571489409245255*^9, 3.571489439110716*^9}, {3.5726970733281813`*^9, 
  3.572697076930201*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"DEE1", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DefTensor", "[", 
   RowBox[{
    RowBox[{"DEE2", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
    RowBox[{"Symmetric", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "a"}], ",", 
       RowBox[{"-", "b"}]}], "}"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.548959692707201*^9, 3.548959712017828*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"DEE1", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`DEE1[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571480749264223*^9, 3.571482748020135*^9, 
  3.571489306498258*^9, 3.5714895597141237`*^9, 3.571899800332543*^9, 
  3.572691369586804*^9, 3.572697084387395*^9, 3.5726981534105473`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"DEE2", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`DEE2[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571480749264223*^9, 3.571482748020135*^9, 
  3.571489306498258*^9, 3.5714895597141237`*^9, 3.571899800332543*^9, 
  3.572691369586804*^9, 3.572697084387395*^9, 3.572698153428348*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DEE1", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"InducedDecomposition", "[", 
      RowBox[{
       RowBox[{"GaussCodazzi", "[", 
        RowBox[{"EE1", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"hh", ",", "u"}], "}"}]}], "]"}], "/.", "ruleProj"}], "//", 
    "NoScalar"}], "//", "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.57269710304661*^9, 3.5726971227739267`*^9}, {
  3.5726981541472073`*^9, 3.572698154807632*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"80", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "-", 
       RowBox[{"36", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"c", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`c, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"d", " "},
                {" ", "d"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`d, -$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[
          RowBox[{"R", "[", "D", "]"}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`RicciScalarcd[],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], 
            SuperscriptBox["D", "c"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`cd[$CellContext`c][
            $CellContext`\[Alpha][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"d", "e"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`d, $CellContext`e],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"d", "e"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`d, -$CellContext`e]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {"d", " "},
                  {" ", "d"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`ExtrinsicKhh[$CellContext`d, -$CellContext`d]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"20", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"9", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"20", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"d"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"9", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"d"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         InterpretationBox[
          StyleBox["Dim",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Dim,
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"d"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             RowBox[{"R", "[", "D", "]"}], 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "a"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {"c", " "},
                  {" ", "c"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`a][
           $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Alpha][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", "c"},
                  {"a", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "e"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`e],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"d", "e"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`d, -$CellContext`e]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {" "},
             {"a"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[-$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {"c", " "},
                  {" ", "c"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", "c"},
                  {"b", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`b, $CellContext`c]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"16", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "80"}], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}], "+", 
          RowBox[{"36", " ", 
           InterpretationBox[
            StyleBox["Dim",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Dim,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["Dim",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Dim,
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}], "-", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"c", "d"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[-$CellContext`c, -$CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {"c", "d"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[$CellContext`c, $CellContext`d],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"]}], "+", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {"c", " "},
                   {" ", "c"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {"d", " "},
                   {" ", "d"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[$CellContext`d, -$CellContext`d],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"]}], "+", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{"R", "[", "D", "]"}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`RicciScalarcd[],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"]}], "-", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"h", 
                StyleBox[GridBox[{
                   {"d", "e"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`hh[$CellContext`d, $CellContext`e],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
                 {"Kh", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"d", "e"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`ExtrinsicKhh[-$CellContext`d, -$CellContext`e]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
                 {"Kh", 
                  StyleBox[GridBox[{
                    {"d", " "},
                    {" ", "d"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`ExtrinsicKhh[$CellContext`d, -$CellContext`d]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"20", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"h", 
                StyleBox[GridBox[{
                   {"c", "d"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`hh[$CellContext`c, $CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "-", 
          RowBox[{"9", " ", 
           InterpretationBox[
            StyleBox["Dim",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Dim,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"h", 
                StyleBox[GridBox[{
                   {"c", "d"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`hh[$CellContext`c, $CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["Dim",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Dim,
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"h", 
                StyleBox[GridBox[{
                   {"c", "d"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`hh[$CellContext`c, $CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "-", 
          RowBox[{"28", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"d"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"11", " ", 
           InterpretationBox[
            StyleBox["Dim",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Dim,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"d"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["Dim",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Dim,
             Editable->False], "2"], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"d"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`d],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"16", " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"d"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}], "-", 
          RowBox[{"4", " ", 
           InterpretationBox[
            StyleBox["Dim",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Dim,
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"d"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.572697100801745*^9, 3.572697125983738*^9}, 
   3.57269815731094*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DEE2", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"InducedDecomposition", "[", 
       RowBox[{
        RowBox[{"GaussCodazzi", "[", 
         RowBox[{"EE2", "[", 
          RowBox[{
           RowBox[{"-", "a"}], ",", 
           RowBox[{"-", "b"}]}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"hh", ",", "u"}], "}"}]}], "]"}], "/.", "ruleProj"}], "//", 
     "NoScalar"}], "//", "MetricToProjector"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.5714808328020906`*^9, 3.5714808975000467`*^9}, {
   3.571486219536317*^9, 3.571486242118525*^9}, {3.5714863286813*^9, 
   3.5714863356075478`*^9}, {3.571489388537404*^9, 3.571489389233459*^9}, 
   3.571489586270091*^9, {3.571489848155942*^9, 3.5714898529938498`*^9}, 
   3.572697134435091*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             RowBox[{"R", "[", "D", "]"}], 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "a"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {"c", " "},
                  {" ", "c"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`a][
           $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Alpha][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", "c"},
                  {"a", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "e"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`e],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"d", "e"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`d, -$CellContext`e]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False]}], ")"}], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"d"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`d],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {" "},
             {"a"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[-$CellContext`a],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["D", "b"], GridBox[{
                 {"Kh", 
                  StyleBox[GridBox[{
                    {"c", " "},
                    {" ", "c"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`b][
              $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c]],
             Editable->False], ")"}]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["D", "c"], GridBox[{
                 {"Kh", 
                  StyleBox[GridBox[{
                    {" ", "c"},
                    {"b", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->9]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`c][
              $CellContext`ExtrinsicKhh[-$CellContext`b, $CellContext`c]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"h", 
                StyleBox[GridBox[{
                   {" ", "d"},
                   {"b", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`hh[-$CellContext`b, $CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"u", 
                StyleBox[GridBox[{
                   {"c"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`u[$CellContext`c],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               InterpretationBox[
                StyleBox[
                 RowBox[{
                  SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`CD[-$CellContext`c][
                 $CellContext`\[Lambda][]],
                Editable->False], ")"}], " ", 
              RowBox[{"(", 
               InterpretationBox[
                StyleBox[
                 RowBox[{
                  SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`CD[-$CellContext`d][
                 $CellContext`\[Lambda][]],
                Editable->False], ")"}]}], "-", 
             RowBox[{"2", " ", 
              InterpretationBox[
               StyleBox["\[Lambda]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Lambda][],
               Editable->False], " ", 
              RowBox[{"(", 
               InterpretationBox[
                StyleBox[
                 RowBox[{
                  SubscriptBox["\[EmptyDownTriangle]", "d"], 
                  SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`CD[-$CellContext`d][
                 $CellContext`CD[-$CellContext`c][
                  $CellContext`\[Lambda][]]],
                Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {" "},
                {"b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[-$CellContext`b],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"c", "d"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[-$CellContext`c, -$CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {"c", "d"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[$CellContext`c, $CellContext`d],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Alpha]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Alpha][],
            Editable->False], " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox[
            InterpretationBox[
             StyleBox["\[Lambda]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Lambda][],
             Editable->False], "2"], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["D", "c"], 
               SuperscriptBox["D", "c"], "\[Alpha]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`cd[-$CellContext`c][
              $CellContext`cd[$CellContext`c][
               $CellContext`\[Alpha][]]],
             Editable->False], ")"}]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox["\[Alpha]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Alpha][],
            Editable->False], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              InterpretationBox[
               StyleBox[GridBox[{
                  {"u", 
                   StyleBox[GridBox[{
                    {"c"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->9]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`u[$CellContext`c],
               Editable->False], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"8", " ", 
                 SuperscriptBox[
                  InterpretationBox[
                   StyleBox["\[Lambda]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`\[Lambda][],
                   Editable->False], "2"], " ", 
                 RowBox[{"(", 
                  InterpretationBox[
                   StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
                    {"Kh", 
                    StyleBox[GridBox[{
                    {"d", " "},
                    {" ", "d"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->9]}
                    },
                    
                    GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}]}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                   $CellContext`CD[-$CellContext`c][
                    $CellContext`ExtrinsicKhh[$CellContext`d, \
-$CellContext`d]],
                   Editable->False], ")"}]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", 
                   InterpretationBox[
                    StyleBox["Dim",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`Dim,
                    Editable->False]}], ")"}], " ", 
                 InterpretationBox[
                  StyleBox[GridBox[{
                    {"u", 
                    StyleBox[GridBox[{
                    {"d"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->9]}
                    },
                    
                    GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`u[$CellContext`d],
                  Editable->False], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", 
                    InterpretationBox[
                    StyleBox["Dim",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`Dim,
                    Editable->False]}], ")"}], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`c][
                    $CellContext`\[Lambda][]],
                    Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`d][
                    $CellContext`\[Lambda][]],
                    Editable->False], ")"}]}], "-", 
                   RowBox[{"2", " ", 
                    InterpretationBox[
                    StyleBox["\[Lambda]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Lambda][],
                    Editable->False], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], 
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`d][
                    $CellContext`CD[-$CellContext`c][
                    $CellContext`\[Lambda][]]],
                    Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", 
                InterpretationBox[
                 StyleBox["Dim",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`Dim,
                 Editable->False]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", 
                   InterpretationBox[
                    StyleBox["Dim",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`Dim,
                    Editable->False]}], ")"}], " ", 
                 InterpretationBox[
                  StyleBox["\[Lambda]",
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`\[Lambda][],
                  Editable->False]}], "-", 
                RowBox[{
                 InterpretationBox[
                  StyleBox[GridBox[{
                    {"h", 
                    StyleBox[GridBox[{
                    {"c", "d"},
                    {" ", " "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->9]}
                    },
                    
                    GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                   ShowAutoStyles->False,
                   AutoSpacing->False],
                  $CellContext`hh[$CellContext`c, $CellContext`d],
                  Editable->False], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    InterpretationBox[
                    StyleBox["Dim",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`Dim,
                    Editable->False]}], ")"}], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`c][
                    $CellContext`\[Lambda][]],
                    Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`d][
                    $CellContext`\[Lambda][]],
                    Editable->False], ")"}]}], "+", 
                   RowBox[{"2", " ", 
                    InterpretationBox[
                    StyleBox["\[Lambda]",
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`\[Lambda][],
                    Editable->False], " ", 
                    RowBox[{"(", 
                    InterpretationBox[
                    StyleBox[
                    RowBox[{
                    SubscriptBox["\[EmptyDownTriangle]", "d"], 
                    SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
                    ShowAutoStyles->False,
                    AutoSpacing->False],
                    $CellContext`CD[-$CellContext`d][
                    $CellContext`CD[-$CellContext`c][
                    $CellContext`\[Lambda][]]],
                    Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.571486220325596*^9, 3.5714862430271797`*^9}, {
   3.571486334233037*^9, 3.5714863362700577`*^9}, 3.5714895873950644`*^9, {
   3.571489857866214*^9, 3.5714898769653673`*^9}, 3.571490459207637*^9, 
   3.57189980410949*^9, 3.572691374198997*^9, 3.5726971373480263`*^9, 
   3.57269816096529*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hamiltonian constraint", "Subsection",
 CellChangeTimes->{{3.5714899245524817`*^9, 3.5714899306098433`*^9}}],

Cell["\<\
The Hamiltonian constraint \[ScriptCapitalH] is given by the contraction of \
the EoMs with the normal vector $u^a$:
\[ScriptCapitalH] = EE1_{ab} u^a u^b = 0\
\>", "Text",
 CellChangeTimes->{{3.571489937680225*^9, 3.571490032124694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp1\[ScriptCapitalH]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp2\[ScriptCapitalH]", "[", "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[ScriptCapitalH]", "[", "]"}], ",", "M"}], "]"}]}], "Input",
 CellChangeTimes->{{3.510492137429859*^9, 3.510492147318773*^9}, {
   3.510573847361595*^9, 3.510573847705432*^9}, {3.5158410329521723`*^9, 
   3.515841033491908*^9}, 3.548529911818277*^9, {3.548530619312461*^9, 
   3.54853062037393*^9}, {3.5489606281161127`*^9, 3.548960632881274*^9}, {
   3.548960941193823*^9, 3.548960944332389*^9}, {3.571482362012498*^9, 
   3.571482374546392*^9}, 3.57149001981104*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp1\[ScriptCapitalH]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp1\[ScriptCapitalH][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571482751913618*^9, 3.571490020909246*^9, 
  3.57189982330647*^9, 3.572691376649123*^9, 3.572697144133527*^9, 
  3.572698163696883*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp2\[ScriptCapitalH]", "[", "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp2\[ScriptCapitalH][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571482751913618*^9, 3.571490020909246*^9, 
  3.57189982330647*^9, 3.572691376649123*^9, 3.572697144133527*^9, 
  3.572698163709517*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalH]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>",
    "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalH][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571482751913618*^9, 3.571490020909246*^9, 
  3.57189982330647*^9, 3.572691376649123*^9, 3.572697144133527*^9, 
  3.572698163711958*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp1\[ScriptCapitalH]", "[", "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "[", "a", "]"}], 
      RowBox[{"u", "[", "b", "]"}], 
      RowBox[{"DEE1", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}]}], "//", "Simplification"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.571480927142761*^9, 3.57148096991194*^9}, 
   3.571490022992221*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "80"}], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{"36", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"a", " "},
             {" ", "a"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"b", " "},
             {" ", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{"R", "[", "D", "]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarcd[],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"b", "c"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`b, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {" ", " "},
               {"b", "c"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`ExtrinsicKhh[-$CellContext`b, -$CellContext`c]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {"b", " "},
               {" ", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"20", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"9", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"28", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"11", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"16", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], 
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"b"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[EmptyDownTriangle]", "b"], 
         SubscriptBox["\[EmptyDownTriangle]", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`b][
        $CellContext`CD[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5714809305343857`*^9, 3.571480970388659*^9}, 
   3.571482753207406*^9, 3.571486253152533*^9, 3.571490025683136*^9, 
   3.571490464798191*^9, 3.57189982435572*^9, 3.57269137831481*^9, 
   3.5726971500341253`*^9, 3.572698165169857*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp2\[ScriptCapitalH]", "[", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToInducedDerivative", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToInducedDerivative", "[", 
         RowBox[{
          RowBox[{"tmp1\[ScriptCapitalH]", "[", "]"}], ",", "CD", ",", "cd"}],
          "]"}], "//", "GradNormalToExtrinsicK"}], "//", "Simplification"}], 
      ",", "CD", ",", "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.572697294308457*^9, 3.572697326474226*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "112"}], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False]}], "+", 
    RowBox[{"44", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False]}], "-", 
    RowBox[{"80", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{"36", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"12", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"a", " "},
             {" ", "a"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"b", " "},
             {" ", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[
       RowBox[{"R", "[", "D", "]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`RicciScalarcd[],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "-", 
    RowBox[{"16", " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Alpha]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Alpha][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Alpha]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Alpha][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"20", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"9", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {"a", "b"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[$CellContext`a, $CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {"a", " "},
               {" ", "a"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"32", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`K\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"8", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`K\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"16", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], 
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"a"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`a],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "u"], 
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`u[$CellContext`a]][
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.5726972893173933`*^9, 3.572697327201626*^9}, 
   3.572698166354905*^9}]
}, Open  ]],

Cell["\<\
The terms  $\\sim \[ScriptCapitalL]_u K_{ab}$ obviously are not simplified in \
the most desireable way. Therefore, we enforce the Leibniz rule. \
Additionally, we substract the appropriate portion of $D\[ScriptCapitalS]=0$ \
in order to substitute terms $\\sim \[ScriptCapitalL]_u K\[Lambda]$\
\>", "Text",
 CellChangeTimes->{{3.571490074720142*^9, 3.571490145752583*^9}, {
  3.571490217100974*^9, 3.571490336236718*^9}, {3.572697422887974*^9, 
  3.572697491880872*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule\[ScriptCapitalH]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"hh", "[", 
      RowBox[{"a_", ",", "b_"}], "]"}], 
     RowBox[{
      RowBox[{"LieD", "[", 
       RowBox[{"u", "[", "c_", "]"}], "]"}], "[", 
      RowBox[{"ExtrinsicKhh", "[", 
       RowBox[{
        RowBox[{"-", "a_"}], ",", 
        RowBox[{"-", "b_"}]}], "]"}], "]"}]}], "\[RuleDelayed]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"d", ",", "e"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"LieD", "[", 
         RowBox[{"u", "[", "c", "]"}], "]"}], "[", 
        RowBox[{"ExtrinsicKhh", "[", 
         RowBox[{"d", ",", 
          RowBox[{"-", "d"}]}], "]"}], "]"}], "-", 
       RowBox[{
        RowBox[{"ExtrinsicKhh", "[", 
         RowBox[{
          RowBox[{"-", "d"}], ",", 
          RowBox[{"-", "e"}]}], "]"}], 
        RowBox[{
         RowBox[{"LieD", "[", 
          RowBox[{"u", "[", "c", "]"}], "]"}], "[", 
         RowBox[{"hh", "[", 
          RowBox[{"d", ",", "e"}], "]"}], "]"}]}]}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalH]", "[", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"tmp2\[ScriptCapitalH]", "[", "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Dim", "-", "4"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", 
             RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], 
          RowBox[{"D\[ScriptCapitalS]", "[", "]"}]}]}], ")"}]}], "/.", 
      "rule\[ScriptCapitalH]"}], "/.", "rule\[Lambda]"}], "//", 
    "Simplification"}], "//", "ContractMetric"}]}]], "Input",
 CellChangeTimes->{{3.572697347068733*^9, 3.5726974017472353`*^9}, {
  3.572697499838357*^9, 3.572697518942631*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"a", "b"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`a, $CellContext`b],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"a", " "},
           {" ", "a"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"b", " "},
           {" ", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{"R", "[", "D", "]"}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciScalarcd[],
   Editable->False], "+", 
  FractionBox[
   RowBox[{"20", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], "2"], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "+", 
  FractionBox["20", 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   SuperscriptBox[
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], "2"], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {"a", " "},
            {" ", "a"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {"a", " "},
            {" ", "a"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[$CellContext`a, -$CellContext`a],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], 
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], 
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`cd[$CellContext`a][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{"7", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"11", " ", 
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], "2"], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.572697343848023*^9, 3.5726973694299383`*^9}, 
   3.5726974025979967`*^9, {3.572697500459402*^9, 3.572697519438982*^9}, 
   3.5726981691764803`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum constraint", "Subsection",
 CellChangeTimes->{{3.571490352842861*^9, 3.571490356167658*^9}}],

Cell["\<\
Next we compute the momentum constraint which is the mixed projection of the \
EoMs:
\[ScriptCapitalM]_i = h^a_i EE1_{ab} u^b\
\>", "Text",
 CellChangeTimes->{{3.571490362441963*^9, 3.571490410326467*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp1\[ScriptCapitalM]", "[", 
    RowBox[{"-", "a"}], "]"}], ",", "M", ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"u", "[", "a", "]"}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"hh", "[", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}]}], "]"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[ScriptCapitalM]", "[", 
    RowBox[{"-", "a"}], "]"}], ",", "M", ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"u", "[", "a", "]"}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"hh", "[", 
      RowBox[{"a", ",", 
       RowBox[{"-", "b"}]}], "]"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.510492895622425*^9, 3.510492908300048*^9}, {
  3.5105746641059933`*^9, 3.5105746653225527`*^9}, {3.548530708334579*^9, 
  3.548530715042053*^9}, {3.548961800170412*^9, 3.548961807438224*^9}, {
  3.57148287478399*^9, 3.571482874971404*^9}, {3.571490418649069*^9, 
  3.571490419128311*^9}, {3.572691383931478*^9, 3.572691384639428*^9}, {
  3.572697537440743*^9, 3.572697540484887*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp1\[ScriptCapitalM]", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp1\[ScriptCapitalM][-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.548530715394793*^9, 3.5489618079383287`*^9, 
  3.571482759001266*^9, 3.57149041967373*^9, 3.5718998321781607`*^9, 
  3.572691385060429*^9, 3.5726975413104258`*^9, 3.5726981728802633`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalM]", "[", 
    RowBox[{"-", "a"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalM][-$CellContext`a], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.548530715394793*^9, 3.5489618079383287`*^9, 
  3.571482759001266*^9, 3.57149041967373*^9, 3.5718998321781607`*^9, 
  3.572691385060429*^9, 3.5726975413104258`*^9, 3.5726981729068203`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp1\[ScriptCapitalM]", "[", 
   RowBox[{"-", "a_"}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b", ",", "c"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"hh", "[", 
        RowBox[{
         RowBox[{"-", "a"}], ",", "b"}], "]"}], 
       RowBox[{"DEE1", "[", 
        RowBox[{
         RowBox[{"-", "b"}], ",", 
         RowBox[{"-", "c"}]}], "]"}], 
       RowBox[{"u", "[", "c", "]"}]}], "//", "Simplification"}], "//", 
     "ContractMetric"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.571482614010372*^9, 3.5714826579629183`*^9}, {
  3.571482829902034*^9, 3.5714828495043907`*^9}, {3.571486270490519*^9, 
  3.5714862709948177`*^9}, {3.5726975473580236`*^9, 3.572697547861311*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "a"], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"b", " "},
           {" ", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`a][
    $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b]],
   Editable->False], "-", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "b"], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", "b"},
           {"a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`b][
    $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`b]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"h", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hh[-$CellContext`a, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {"b"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[$CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hh[-$CellContext`a, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {"b"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[$CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`c][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hh[-$CellContext`a, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {"b"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[$CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "c"], 
        SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"h", 
         StyleBox[GridBox[{
            {" ", "c"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`hh[-$CellContext`a, $CellContext`c],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {"b"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[$CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["\[EmptyDownTriangle]", "c"], 
        SubscriptBox["\[EmptyDownTriangle]", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`c][
       $CellContext`CD[-$CellContext`b][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{{3.571482622165914*^9, 3.5714826583374968`*^9}, 
   3.571482760778167*^9, 3.5714828518770933`*^9, {3.571486266401992*^9, 
   3.571486271461875*^9}, 3.571490420623396*^9, 3.571490470320414*^9, 
   3.571899833310964*^9, 3.572691385920218*^9, 3.572697548921756*^9, 
   3.572698173930792*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalM]", "[", 
   RowBox[{"-", "a_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ToInducedDerivative", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ToInducedDerivative", "[", 
          RowBox[{
           RowBox[{"tmp1\[ScriptCapitalM]", "[", 
            RowBox[{"-", "a"}], "]"}], ",", "CD", ",", "cd"}], "]"}], "//", 
         "GradNormalToExtrinsicK"}], "//", "Simplification"}], ",", "CD", ",",
        "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
    "Simplification"}], "//", "ContractMetric"}]}]], "Input",
 CellChangeTimes->{{3.572697551807149*^9, 3.572697612282686*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "a"], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"b", " "},
           {" ", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`a][
    $CellContext`ExtrinsicKhh[$CellContext`b, -$CellContext`b]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "K\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`K\[Lambda][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "K\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`K\[Lambda][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], "-", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["D", "b"], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", "b"},
           {"a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[-$CellContext`b][
    $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`b]],
   Editable->False], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {" ", "b"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {" ", "b"},
            {"a", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`b],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]]}]], "Output",
 CellChangeTimes->{{3.572697555434452*^9, 3.572697613351109*^9}, 
   3.57269817504519*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["spatial projection and evolution equation for K_{ij}", "Subsection",
 CellChangeTimes->{{3.571490482018386*^9, 3.571490498625695*^9}}],

Cell["\<\
The last possible projection of the Einstein\[CloseCurlyQuote]s equations is \
the fully spatial one. As we will see, this calculations leads to the \
evolution equation for the extrinsic curvature. Together with its definition \
$\[ScriptCapitalL]_u h_{ab} = -2 K_{ab}$ we obtain a closed system of \
evolution equations.
In this case it is convenient to perform the split on the second form of the \
EoMs, i.e., 
\[ScriptCapitalP]_{ab} = h^c_a h^d_b EE2_{cd}\
\>", "Text",
 CellChangeTimes->{{3.571490502181134*^9, 3.571490707039592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp1\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "a", "]"}], ",", 
      RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", 
      RowBox[{"hh", "[", 
       RowBox[{"b", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"tmp2\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "a", "]"}], ",", 
      RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", 
      RowBox[{"hh", "[", 
       RowBox[{"b", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "a", "]"}], ",", 
      RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", 
      RowBox[{"hh", "[", 
       RowBox[{"b", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.510494970417485*^9, 3.510494984089965*^9}, {
  3.511171288389538*^9, 3.511171289353198*^9}, {3.548531434764057*^9, 
  3.548531440606073*^9}, {3.548962610908321*^9, 3.548962617501334*^9}, {
  3.571490716419829*^9, 3.571490722103978*^9}, {3.572697665826687*^9, 
  3.572697668056706*^9}, {3.57269818463766*^9, 3.572698184936672*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp1\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp1\[ScriptCapitalP][-$CellContext`a, -$CellContext`b], ". ",
    ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.510495177455578*^9, 3.510495215695858*^9, 
  3.510568811327133*^9, 3.5105747816182756`*^9, 3.510934401971734*^9, 
  3.510995264020941*^9, 3.511078719068315*^9, 3.511171278224705*^9, 
  3.511461421739312*^9, 3.51152986950711*^9, 3.511533354317107*^9, 
  3.511788245913721*^9, 3.5118724724408407`*^9, 3.512209770290101*^9, 
  3.51221094234158*^9, 3.5122150554145803`*^9, 3.5123753863665237`*^9, 
  3.513933198020352*^9, 3.5157495368124313`*^9, 3.548531441383498*^9, 
  3.548962618020677*^9, 3.5714856094784927`*^9, 3.571490719235618*^9, 
  3.57189983745575*^9, 3.572691389141303*^9, 3.572697621612162*^9, 
  3.57269766834265*^9, 3.572698185308949*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"tmp2\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`tmp2\[ScriptCapitalP][-$CellContext`a, -$CellContext`b], ". ",
    ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.510495177455578*^9, 3.510495215695858*^9, 
  3.510568811327133*^9, 3.5105747816182756`*^9, 3.510934401971734*^9, 
  3.510995264020941*^9, 3.511078719068315*^9, 3.511171278224705*^9, 
  3.511461421739312*^9, 3.51152986950711*^9, 3.511533354317107*^9, 
  3.511788245913721*^9, 3.5118724724408407`*^9, 3.512209770290101*^9, 
  3.51221094234158*^9, 3.5122150554145803`*^9, 3.5123753863665237`*^9, 
  3.513933198020352*^9, 3.5157495368124313`*^9, 3.548531441383498*^9, 
  3.548962618020677*^9, 3.5714856094784927`*^9, 3.571490719235618*^9, 
  3.57189983745575*^9, 3.572691389141303*^9, 3.572697621612162*^9, 
  3.57269766834265*^9, 3.5726981853525543`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[ScriptCapitalP]", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[ScriptCapitalP][-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.510495177455578*^9, 3.510495215695858*^9, 
  3.510568811327133*^9, 3.5105747816182756`*^9, 3.510934401971734*^9, 
  3.510995264020941*^9, 3.511078719068315*^9, 3.511171278224705*^9, 
  3.511461421739312*^9, 3.51152986950711*^9, 3.511533354317107*^9, 
  3.511788245913721*^9, 3.5118724724408407`*^9, 3.512209770290101*^9, 
  3.51221094234158*^9, 3.5122150554145803`*^9, 3.5123753863665237`*^9, 
  3.513933198020352*^9, 3.5157495368124313`*^9, 3.548531441383498*^9, 
  3.548962618020677*^9, 3.5714856094784927`*^9, 3.571490719235618*^9, 
  3.57189983745575*^9, 3.572691389141303*^9, 3.572697621612162*^9, 
  3.57269766834265*^9, 3.5726981853558197`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp1\[ScriptCapitalP]", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"hh", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", "c"}], "]"}], 
      RowBox[{"hh", "[", 
       RowBox[{
        RowBox[{"-", "b"}], ",", "d"}], "]"}], 
      RowBox[{"DEE2", "[", 
       RowBox[{
        RowBox[{"-", "c"}], ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "//", "Simplification"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5714856204113073`*^9, 3.5714856922423973`*^9}, 
   3.5714907252757807`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             RowBox[{"R", "[", "D", "]"}], 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Alpha][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "e"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`e],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"d", "e"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`ExtrinsicKhh[-$CellContext`d, -$CellContext`e]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[EmptyDownTriangle]", "d"], 
            SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`d][
           $CellContext`CD[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False]}], ")"}], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          InterpretationBox[
           StyleBox["Dim",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Dim,
           Editable->False]}], ")"}], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {"c", "d"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[$CellContext`c, $CellContext`d],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"d"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`d],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`c][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`\[Lambda][]],
             Editable->False], ")"}]}], "+", 
          RowBox[{"2", " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               SubscriptBox["\[EmptyDownTriangle]", "d"], 
               SubscriptBox["\[EmptyDownTriangle]", "c"], "\[Lambda]"}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`CD[-$CellContext`d][
              $CellContext`CD[-$CellContext`c][
               $CellContext`\[Lambda][]]],
             Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.571485625358226*^9, 3.571485692637301*^9}, 
   3.5714862797131042`*^9, 3.571486342879245*^9, 3.5714907292254066`*^9, 
   3.5718998388201513`*^9, 3.572691391239233*^9, 3.5726976232236233`*^9, 
   3.572698186618093*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tmp2\[ScriptCapitalP]", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToInducedDerivative", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToInducedDerivative", "[", 
         RowBox[{
          RowBox[{"tmp1\[ScriptCapitalP]", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", 
            RowBox[{"-", "b"}]}], "]"}], ",", "CD", ",", "cd"}], "]"}], "//", 
        "GradNormalToExtrinsicK"}], "//", "Simplification"}], ",", "CD", ",", 
      "cd"}], "]"}], "//", "GradNormalToExtrinsicK"}], "//", 
   "Simplification"}]}]], "Input",
 CellChangeTimes->{{3.571485694843112*^9, 3.571485765006405*^9}, 
   3.571490733123624*^9, {3.572697632876696*^9, 3.572697650920125*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    InterpretationBox[
     StyleBox["\[Alpha]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Alpha][],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"b", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`b, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             RowBox[{"R", "[", "D", "]"}], 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             InterpretationBox[
              StyleBox["Dim",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Dim,
              Editable->False]}], ")"}], " ", 
           InterpretationBox[
            StyleBox["K\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`K\[Lambda][],
            Editable->False]}], "+", 
          RowBox[{
           InterpretationBox[
            StyleBox[GridBox[{
               {"Kh", 
                StyleBox[GridBox[{
                   {"c", " "},
                   {" ", "c"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->9]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
            Editable->False], " ", 
           InterpretationBox[
            StyleBox["\[Lambda]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Lambda][],
            Editable->False]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`a][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`a][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Alpha][]]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"8", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "b"], 
            SubscriptBox["D", "a"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`b][
           $CellContext`cd[-$CellContext`a][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "c"},
                {"a", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`a, $CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"h", 
             StyleBox[GridBox[{
                {" ", "d"},
                {"b", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`hh[-$CellContext`b, $CellContext`d],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Lambda][],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[ScriptCapitalL]", "u"], GridBox[{
              {"Kh", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"c", "d"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->9]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`LieD[
           $CellContext`u[$CellContext`a]][
           $CellContext`ExtrinsicKhh[-$CellContext`c, -$CellContext`d]],
          Editable->False], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       InterpretationBox[
        StyleBox["Dim",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Dim,
        Editable->False]}], ")"}], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"h", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`hh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "24"}], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["K\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`K\[Lambda][],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox["K\[Lambda]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`K\[Lambda][],
          Editable->False], "2"], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False]}], "-", 
       RowBox[{"20", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "+", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {"c", " "},
                {" ", "c"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["K\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`K\[Lambda][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], 
            SuperscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`cd[$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["D", "c"], "\[Alpha]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`c][
           $CellContext`\[Alpha][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"6", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{
        InterpretationBox[
         StyleBox["Dim",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Dim,
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[-$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SuperscriptBox["D", "c"], "\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`cd[$CellContext`c][
           $CellContext`\[Lambda][]],
          Editable->False], ")"}]}], "-", 
       RowBox[{"4", " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[ScriptCapitalL]", "u"], "K\[Lambda]"}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`LieD[
           $CellContext`u[$CellContext`a]][
           $CellContext`K\[Lambda][]],
          Editable->False], ")"}]}], "+", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {"u", 
             StyleBox[GridBox[{
                {"c"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`u[$CellContext`c],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Alpha]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Alpha][],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox["\[Lambda]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Lambda][],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox["\[ScriptCapitalL]", "u"], 
            RowBox[{
             SubscriptBox["D", "c"], "\[Lambda]"}]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xTensor`LieD[
           $CellContext`u[$CellContext`a]][
           $CellContext`cd[-$CellContext`c][
            $CellContext`\[Lambda][]]],
          Editable->False], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.571485701946143*^9, 3.571485731537917*^9}, 
   3.571485765691485*^9, 3.57148628234933*^9, 3.571486343854888*^9, 
   3.571490733514626*^9, 3.571899841287026*^9, 3.572691392313369*^9, {
   3.572697629261841*^9, 3.5726976520902853`*^9}, 3.5726981886199007`*^9}]
}, Open  ]],

Cell["\<\
Again, there are terms that have not been simplified in the most desireable \
form and we enforce the Leibnizrule again.  We also need to substitute the \
scalar field EoM for terms $\\sim \[ScriptCapitalL]_u K\[Lambda]$.
Thus, we arrive at a prescription for \[ScriptCapitalL]_u K_{ij} -- the time \
evolution equation for K_{ij}\
\>", "Text",
 CellChangeTimes->{{3.571490748541123*^9, 3.571490841544073*^9}, {
  3.572697677490685*^9, 3.572697734611389*^9}, {3.572697845333705*^9, 
  3.5726978811887417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rule\[ScriptCapitalP]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"hh", "[", 
      RowBox[{
       RowBox[{"-", "a_"}], ",", "c_"}], "]"}], 
     RowBox[{"hh", "[", 
      RowBox[{
       RowBox[{"-", "b_"}], ",", "d_"}], "]"}], 
     RowBox[{
      RowBox[{"LieD", "[", 
       RowBox[{"u", "[", "e_", "]"}], "]"}], "[", 
      RowBox[{"ExtrinsicKhh", "[", 
       RowBox[{
        RowBox[{"-", "c_"}], ",", 
        RowBox[{"-", "d_"}]}], "]"}], "]"}]}], "\[RuleDelayed]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"f", ",", "g"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"LieD", "[", 
         RowBox[{"u", "[", "c", "]"}], "]"}], "[", 
        RowBox[{"ExtrinsicKhh", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], "]"}], "-", 
       RowBox[{
        RowBox[{"ExtrinsicKhh", "[", 
         RowBox[{
          RowBox[{"-", "f"}], ",", 
          RowBox[{"-", "g"}]}], "]"}], 
        RowBox[{
         RowBox[{"LieD", "[", 
          RowBox[{"u", "[", "c", "]"}], "]"}], "[", 
         RowBox[{
          RowBox[{"hh", "[", 
           RowBox[{
            RowBox[{"-", "a"}], ",", "f"}], "]"}], 
          RowBox[{"hh", "[", 
           RowBox[{
            RowBox[{"-", "b"}], ",", "g"}], "]"}]}], "]"}]}]}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.571485772582898*^9, 3.5714858625324907`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalP]", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"tmp2\[ScriptCapitalP]", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], "-", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Dim", "-", "4"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", 
            RowBox[{"\[Lambda]", "[", "]"}]}], ")"}]}], 
         RowBox[{"hh", "[", 
          RowBox[{
           RowBox[{"-", "a"}], ",", 
           RowBox[{"-", "b"}]}], "]"}], 
         RowBox[{"D\[ScriptCapitalS]", "[", "]"}]}]}], ")"}], "/.", 
      "rule\[ScriptCapitalP]"}], "/.", "rule\[Lambda]"}], "//", 
    "Simplification"}], "//", "ContractMetric"}]}]], "Input",
 CellChangeTimes->{{3.572697741171536*^9, 3.5726978269578943`*^9}, {
  3.572697893110631*^9, 3.572697899613452*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", "c"},
           {"a", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", " "},
           {"b", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[-$CellContext`b, -$CellContext`c],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {"c", " "},
           {" ", "c"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", "D", "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"a", "b"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->9]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
   Editable->False], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"Kh", 
         StyleBox[GridBox[{
            {" ", " "},
            {"a", "b"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->9]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox["K\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`K\[Lambda][],
     Editable->False]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`a][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`\[Lambda][]],
      Editable->False], ")"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   InterpretationBox[
    StyleBox[
     RowBox[{
      SubscriptBox["D", "b"], 
      SubscriptBox["D", "a"], "\[Alpha]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`cd[-$CellContext`b][
     $CellContext`cd[-$CellContext`a][
      $CellContext`\[Alpha][]]],
    Editable->False], 
   InterpretationBox[
    StyleBox["\[Alpha]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Alpha][],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], 
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox["\[Lambda]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Lambda][],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox["Dim",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Dim,
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox["D", "b"], 
        SubscriptBox["D", "a"], "\[Lambda]"}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`b][
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]]],
      Editable->False], ")"}]}], 
   RowBox[{"2", " ", 
    InterpretationBox[
     StyleBox["\[Lambda]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Lambda][],
     Editable->False]}]], "-", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", "u"], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    $CellContext`u[$CellContext`a]][
    $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b]],
   Editable->False]}]], "Output",
 CellChangeTimes->{{3.572697751549322*^9, 3.572697780294242*^9}, 
   3.5726978274068823`*^9, 3.572697900348278*^9, 3.572698191931375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["explicit time evolution", "Subsection",
 CellChangeTimes->{{3.571491994888405*^9, 3.571492003047883*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s perform a last change of variables to bring the time \
evolution equations in an explicit form. Therefore, remember that the time \
parameter $t$ is related to the lapse function \[Alpha] and shift vector \
\[Beta]^i :
t^a = \[Alpha] u^a + \[Beta]^a
Then the Lie derivative along u^a is given by 
\[ScriptCapitalL]_u = 1/\[Alpha] (\\partial_t - \[ScriptCapitalL]_\[Beta] )
We have already defined these parameters for the scalar field EoM above\
\>", "Text",
 CellChangeTimes->{{3.571492023630519*^9, 3.571492193945265*^9}, {
  3.571492413890341*^9, 3.571492414392048*^9}, {3.5726979163483257`*^9, 
  3.5726979331747923`*^9}}],

Cell["\<\
We now impose this rule on the spatial projection of Einstein\
\[CloseCurlyQuote]s equations and solve for $\\partial_t K_{ij}$.\
\>", "Text",
 CellChangeTimes->{{3.57149241022152*^9, 3.5714924537232933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"dtKij", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], ",", "M", ",", 
   RowBox[{"Symmetric", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "}"}], "]"}], ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "a", "]"}], ",", 
      RowBox[{"u", "[", "b", "]"}]}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"hh", "[", 
       RowBox[{"a", ",", 
        RowBox[{"-", "c"}]}], "]"}], ",", 
      RowBox[{"hh", "[", 
       RowBox[{"b", ",", 
        RowBox[{"-", "d"}]}], "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571492275886189*^9, 3.571492300853351*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"dtKij", "[", 
    RowBox[{
     RowBox[{"-", "a"}], ",", 
     RowBox[{"-", "b"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`dtKij[-$CellContext`a, -$CellContext`b], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.571492302049062*^9, 3.5718998606123543`*^9, 
  3.572691400965912*^9, 3.572697941681904*^9, 3.5726981961045847`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ruledtKij", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ScriptCapitalP]", "[", 
         RowBox[{
          RowBox[{"-", "a"}], ",", 
          RowBox[{"-", "b"}]}], "]"}], "/.", "ruleLieu"}], ")"}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"LieD", "[", "t", "]"}], "[", 
      RowBox[{"ExtrinsicKhh", "[", 
       RowBox[{
        RowBox[{"-", "a"}], ",", 
        RowBox[{"-", "b"}]}], "]"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5714922340661707`*^9, 3.57149225657306*^9}, {
  3.571492306533511*^9, 3.571492321294832*^9}, {3.571492353624301*^9, 
  3.571492360774292*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", 
      TagBox[
       InterpretationBox[
        StyleBox["t",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`t,
        Editable->False],
       Short]], GridBox[{
       {"Kh", 
        StyleBox[GridBox[{
           {" ", " "},
           {"a", "b"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->9]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[$CellContext`t][
    $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b]],
   Editable->False], "\[Rule]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["K\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`K\[Lambda][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False]}], "-", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", "c"},
              {"a", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", " "},
              {"b", "c"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`b, -$CellContext`c],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], "2"]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"Kh", 
           StyleBox[GridBox[{
              {"c", " "},
              {" ", "c"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], "2"]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", "D", "]"}], 
           StyleBox[GridBox[{
              {" ", " "},
              {"a", "b"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->9]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], "2"]}], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`\[Lambda][]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], 
          SubscriptBox["D", "a"], "\[Alpha]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Alpha][]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], 
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox["Dim",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Dim,
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Alpha]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Alpha][],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["D", "b"], 
          SubscriptBox["D", "a"], "\[Lambda]"}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`b][
         $CellContext`cd[-$CellContext`a][
          $CellContext`\[Lambda][]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["\[Lambda]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Lambda][],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox["\[ScriptCapitalL]", "\[Beta]i"], GridBox[{
            {"Kh", 
             StyleBox[GridBox[{
                {" ", " "},
                {"a", "b"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->9]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`LieD[
         $CellContext`\[Beta]i[$CellContext`a]][
         $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.571492257129302*^9, {3.571492308875369*^9, 3.571492321842141*^9}, 
   3.571899865518251*^9, 3.572691403836198*^9, 3.5726979451863194`*^9, 
   3.572698197031823*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dtKij", "[", 
   RowBox[{
    RowBox[{"-", "a_"}], ",", 
    RowBox[{"-", "b_"}]}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"LieD", "[", "t", "]"}], "[", 
    RowBox[{"ExtrinsicKhh", "[", 
     RowBox[{
      RowBox[{"-", "a"}], ",", 
      RowBox[{"-", "b"}]}], "]"}], "]"}], "/.", "ruledtKij"}]}]], "Input",
 CellChangeTimes->{{3.571492324509399*^9, 3.571492374961005*^9}, {
  3.571492471139482*^9, 3.571492474416257*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "16"}], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["K\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`K\[Lambda][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False]}], "-", 
    RowBox[{"8", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", "c"},
             {"a", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, $CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"b", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`b, -$CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"Kh", 
          StyleBox[GridBox[{
             {"c", " "},
             {" ", "c"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ExtrinsicKhh[$CellContext`c, -$CellContext`c],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "+", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {
          RowBox[{"R", "[", "D", "]"}], 
          StyleBox[GridBox[{
             {" ", " "},
             {"a", "b"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->9]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Riccicd[-$CellContext`a, -$CellContext`b],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"]}], "-", 
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "+", 
    RowBox[{
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`a][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "b"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`\[Lambda][]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "b"], 
         SubscriptBox["D", "a"], "\[Alpha]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Alpha][]]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"8", " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "b"], 
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}], "-", 
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox["Dim",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Dim,
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Alpha]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Alpha][],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox["\[Lambda]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Lambda][],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["D", "b"], 
         SubscriptBox["D", "a"], "\[Lambda]"}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`b][
        $CellContext`cd[-$CellContext`a][
         $CellContext`\[Lambda][]]],
       Editable->False], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox["\[Lambda]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Lambda][],
       Editable->False], "2"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalL]", "\[Beta]i"], GridBox[{
           {"Kh", 
            StyleBox[GridBox[{
               {" ", " "},
               {"a", "b"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->9]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`LieD[
        $CellContext`\[Beta]i[$CellContext`a]][
        $CellContext`ExtrinsicKhh[-$CellContext`a, -$CellContext`b]],
       Editable->False], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.571899866836966*^9, 3.5726914046943283`*^9, 
  3.572697947643211*^9, 3.572698198476067*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export as tex files", "Section",
 CellChangeTimes->{{3.571491049389371*^9, 3.571491054717066*^9}}],

Cell["\<\
xtensor gives the possibility to export mathematical expressions as \
tex-files, which is very convenient for writing up notes/ papers/ etc. \
Therefore we have to load the package \[OpenCurlyDoubleQuote]TexAct\
\[CloseCurlyDoubleQuote].  Note, that we set the gravitiational constant to \
G_D=1 in the \[OpenCurlyDoubleQuote]printed\[CloseCurlyDoubleQuote] version.\
\>", "Text",
 CellChangeTimes->{{3.571490900944243*^9, 3.571491012415357*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xAct/TexAct.m"}]], "Input",
 CellChangeTimes->{{3.571486701300829*^9, 3.5714867030822897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.572698201576174*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`TexAct`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.3.0\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2012", ",", "5", ",", "5"}], "}"}]}],
  SequenceForm["Package xAct`TexAct`  version ", "0.3.0", ", ", {2012, 5, 5}],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.5726982015920753`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2008-2012, Thomas B\[ADoubleDot]ckdahl, Jose \
M. Martin-Garcia and Barry Wardell, under the General Public License.\"\>"], \
"Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.572698201594284*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.572698201595828*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.5726982015976133`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.5714867037992897`*^9, 3.571490892899129*^9, 
  3.571899872041253*^9, 3.5726914076788816`*^9, 3.5726979539555387`*^9, 
  3.572698201600205*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<TexFiles_DimReduction/Hamiltonian.tex\>\"", ",", 
    RowBox[{"TexPrint", "[", 
     RowBox[{"\[ScriptCapitalH]", "[", "]"}], "]"}], ",", "\"\<Text\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<TexFiles_DimReduction/Momentum.tex\>\"", ",", 
    RowBox[{"TexPrint", "[", 
     RowBox[{"\[ScriptCapitalM]", "[", 
      RowBox[{"-", "i"}], "]"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<TexFiles_DimReduction/dtKij.tex\>\"", ",", 
    RowBox[{"TexPrint", "[", 
     RowBox[{"dtKij", "[", 
      RowBox[{
       RowBox[{"-", "i"}], ",", 
       RowBox[{"-", "j"}]}], "]"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<TexFiles_DimReduction/dtKlambda.tex\>\"", ",", 
    RowBox[{"TexPrint", "[", 
     RowBox[{"dtK\[Lambda]", "[", "]"}], "]"}], ",", "\"\<Text\>\""}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.512210673395637*^9, 3.5122106764909267`*^9}, {
  3.5122108012543163`*^9, 3.512210801310646*^9}, {3.5122172890406847`*^9, 
  3.512217300143197*^9}, {3.515749000745455*^9, 3.515749004125379*^9}, {
  3.571486382856349*^9, 3.571486397351109*^9}, {3.571486428337179*^9, 
  3.571486429362389*^9}, {3.571486459523292*^9, 3.57148647391564*^9}, {
  3.5714865087428093`*^9, 3.5714865237257853`*^9}, {3.5714867522227383`*^9, 
  3.57148677698002*^9}, {3.571492483360283*^9, 3.571492484214876*^9}, {
  3.572691260552844*^9, 3.572691276168798*^9}, {3.572697961837378*^9, 
  3.572698004994589*^9}}]
}, Open  ]]
},
WindowSize->{1277, 680},
WindowMargins->{{-23, Automatic}, {Automatic, -58}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 285, 5, 43, "Input"],
Cell[833, 27, 730, 11, 123, "Text"],
Cell[CellGroupData[{
Cell[1588, 42, 100, 1, 106, "Section"],
Cell[1691, 45, 197, 5, 43, "Text"],
Cell[CellGroupData[{
Cell[1913, 54, 427, 7, 71, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2343, 63, 782, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3128, 79, 1049, 21, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[4180, 102, 803, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[4986, 118, 762, 13, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[5751, 133, 743, 13, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6497, 148, 782, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[7282, 164, 1053, 21, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[8338, 187, 803, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9144, 203, 782, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9929, 219, 937, 16, 88, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[10869, 237, 782, 14, 33, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[11666, 254, 452, 9, 148, "Text"],
Cell[12121, 265, 543, 13, 98, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[12701, 283, 287, 4, 106, "Section"],
Cell[CellGroupData[{
Cell[13013, 291, 111, 1, 55, "Subsection"],
Cell[13127, 294, 604, 11, 123, "Text"],
Cell[CellGroupData[{
Cell[13756, 309, 138, 2, 43, "Input"],
Cell[13897, 313, 595, 11, 33, "Print"]
}, Open  ]],
Cell[14507, 327, 615, 16, 43, "Input"],
Cell[15125, 345, 1143, 22, 71, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[16293, 371, 1843, 30, 33, "Print"],
Cell[18139, 403, 1853, 30, 33, "Print"],
Cell[19995, 435, 2005, 35, 33, "Print"],
Cell[22003, 472, 2111, 38, 33, "Print"],
Cell[24117, 512, 2074, 36, 33, "Print"],
Cell[26194, 550, 2090, 36, 33, "Print"],
Cell[28287, 588, 1930, 33, 33, "Print"],
Cell[30220, 623, 2051, 36, 33, "Print"],
Cell[32274, 661, 2069, 37, 33, "Print"],
Cell[34346, 700, 2094, 37, 33, "Print"],
Cell[36443, 739, 2011, 35, 33, "Print"],
Cell[38457, 776, 1520, 22, 33, "Print"],
Cell[39980, 800, 1897, 31, 33, "Print"],
Cell[41880, 833, 1524, 22, 33, "Print"],
Cell[43407, 857, 2029, 36, 33, "Print"],
Cell[45439, 895, 2082, 36, 33, "Print"],
Cell[47524, 933, 2023, 35, 33, "Print"],
Cell[49550, 970, 1909, 31, 33, "Print"],
Cell[51462, 1003, 1657, 26, 33, "Print"],
Cell[53122, 1031, 1647, 26, 33, "Print"],
Cell[54772, 1059, 1659, 26, 33, "Print"],
Cell[56434, 1087, 1915, 31, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58398, 1124, 106, 1, 55, "Subsection"],
Cell[58507, 1127, 231, 5, 43, "Text"],
Cell[58741, 1134, 1627, 41, 125, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[60371, 1177, 690, 13, 33, "Print"],
Cell[61064, 1192, 558, 9, 96, "Text"],
Cell[CellGroupData[{
Cell[61647, 1205, 713, 18, 43, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[62363, 1225, 1103, 23, 33, "Message",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[CellGroupData[{
Cell[63503, 1253, 1158, 25, 33, "Print"],
Cell[64664, 1280, 1218, 27, 33, "Print"],
Cell[65885, 1309, 1221, 26, 33, "Print"],
Cell[67109, 1337, 1243, 26, 33, "Print"],
Cell[68355, 1365, 1084, 23, 33, "Print"],
Cell[69442, 1390, 1204, 26, 33, "Print"],
Cell[70649, 1418, 1222, 27, 33, "Print"],
Cell[71874, 1447, 1248, 27, 33, "Print"],
Cell[73125, 1476, 1166, 25, 33, "Print"],
Cell[74294, 1503, 669, 12, 33, "Print"],
Cell[74966, 1517, 1046, 21, 33, "Print"],
Cell[76015, 1540, 677, 12, 33, "Print"],
Cell[76695, 1554, 1182, 26, 33, "Print"],
Cell[77880, 1582, 1233, 26, 33, "Print"],
Cell[79116, 1610, 1174, 25, 33, "Print"],
Cell[80293, 1637, 1058, 21, 33, "Print"],
Cell[81354, 1660, 808, 16, 33, "Print"],
Cell[82165, 1678, 796, 16, 33, "Print"],
Cell[82964, 1696, 808, 16, 33, "Print"],
Cell[83775, 1714, 1064, 21, 33, "Print"],
Cell[84842, 1737, 1184, 24, 33, "Print"],
Cell[86029, 1763, 1127, 22, 33, "Print"],
Cell[87159, 1787, 1042, 21, 33, "Print"]
}, Open  ]],
Cell[88216, 1811, 354, 6, 70, "Text"],
Cell[88573, 1819, 316, 7, 43, "Input"],
Cell[88892, 1828, 310, 6, 69, "Text"],
Cell[89205, 1836, 1119, 26, 98, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[90327, 1864, 1025, 20, 33, "Print"],
Cell[CellGroupData[{
Cell[91377, 1888, 101, 1, 40, "Subsubsection"],
Cell[91481, 1891, 996, 31, 71, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[92538, 1929, 193, 4, 106, "Section"],
Cell[CellGroupData[{
Cell[92756, 1937, 927, 25, 179, "Input"],
Cell[CellGroupData[{
Cell[93708, 1966, 523, 10, 33, "Print"],
Cell[94234, 1978, 525, 10, 33, "Print"],
Cell[94762, 1990, 547, 10, 33, "Print"],
Cell[95312, 2002, 547, 10, 33, "Print"],
Cell[95862, 2014, 541, 10, 33, "Print"],
Cell[96406, 2026, 541, 10, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[96974, 2040, 331, 6, 43, "Text"],
Cell[97308, 2048, 379, 10, 43, "Input"],
Cell[97690, 2060, 152, 3, 43, "Text"],
Cell[CellGroupData[{
Cell[97867, 2067, 1260, 39, 98, "Input"],
Cell[99130, 2108, 3976, 122, 68, "Output"]
}, Open  ]],
Cell[103121, 2233, 268, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[103414, 2242, 518, 13, 43, "Input"],
Cell[103935, 2257, 7506, 223, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111478, 2485, 633, 16, 98, "Input"],
Cell[112114, 2503, 7115, 240, 113, "Output"]
}, Open  ]],
Cell[119244, 2746, 171, 4, 43, "Text"],
Cell[CellGroupData[{
Cell[119440, 2754, 876, 26, 43, "Input"],
Cell[120319, 2782, 3527, 104, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123883, 2891, 243, 6, 43, "Input"],
Cell[124129, 2899, 5658, 196, 113, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129824, 3100, 111, 1, 55, "Subsection"],
Cell[129938, 3103, 558, 10, 148, "Text"],
Cell[CellGroupData[{
Cell[130521, 3117, 477, 13, 71, "Input"],
Cell[CellGroupData[{
Cell[131023, 3134, 590, 12, 33, "Print"],
Cell[131616, 3148, 634, 12, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[132299, 3166, 503, 16, 43, "Input"],
Cell[132805, 3184, 1434, 50, 62, "Output"]
}, Open  ]],
Cell[134254, 3237, 250, 5, 43, "Text"],
Cell[CellGroupData[{
Cell[134529, 3246, 235, 5, 43, "Input"],
Cell[134767, 3253, 649, 12, 33, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135453, 3270, 663, 17, 43, "Input"],
Cell[136119, 3289, 8522, 277, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144678, 3571, 386, 10, 43, "Input"],
Cell[145067, 3583, 7777, 260, 93, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[152905, 3850, 284, 6, 106, "Section"],
Cell[153192, 3858, 244, 5, 43, "Text"],
Cell[CellGroupData[{
Cell[153461, 3867, 190, 4, 55, "Subsection"],
Cell[CellGroupData[{
Cell[153676, 3875, 954, 29, 71, "Input"],
Cell[CellGroupData[{
Cell[154655, 3908, 664, 14, 33, "Print"],
Cell[155322, 3924, 664, 14, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[156013, 3942, 198, 4, 43, "Text"],
Cell[CellGroupData[{
Cell[156236, 3950, 2150, 68, 152, "Input"],
Cell[158389, 4020, 6682, 197, 91, "Output"]
}, Open  ]],
Cell[165086, 4220, 158, 3, 43, "Text"],
Cell[CellGroupData[{
Cell[165269, 4227, 566, 18, 43, "Input"],
Cell[165838, 4247, 29142, 761, 160, "Output"]
}, Open  ]],
Cell[194995, 5011, 414, 7, 149, "Text"],
Cell[CellGroupData[{
Cell[195434, 5022, 105, 1, 41, "Subsubsection"],
Cell[CellGroupData[{
Cell[195564, 5027, 369, 9, 71, "Input"],
Cell[CellGroupData[{
Cell[195958, 5040, 556, 11, 33, "Print"],
Cell[196517, 5053, 548, 11, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[197114, 5070, 1017, 28, 152, "Input"],
Cell[198134, 5100, 6716, 207, 96, "Output"]
}, Open  ]],
Cell[204865, 5310, 341, 6, 43, "Text"],
Cell[CellGroupData[{
Cell[205231, 5320, 645, 18, 43, "Input"],
Cell[205879, 5340, 5697, 179, 96, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[211625, 5525, 105, 1, 41, "Subsubsection"],
Cell[CellGroupData[{
Cell[211755, 5530, 947, 28, 71, "Input"],
Cell[CellGroupData[{
Cell[212727, 5562, 549, 11, 33, "Print"],
Cell[213279, 5575, 557, 11, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[213885, 5592, 597, 20, 43, "Input"],
Cell[214485, 5614, 3868, 119, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218390, 5738, 704, 19, 125, "Input"],
Cell[219097, 5759, 3308, 103, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[222454, 5868, 151, 3, 41, "Subsubsection"],
Cell[CellGroupData[{
Cell[222630, 5875, 1687, 54, 125, "Input"],
Cell[CellGroupData[{
Cell[224342, 5933, 615, 13, 33, "Print"],
Cell[224960, 5948, 623, 13, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[225632, 5967, 779, 25, 71, "Input"],
Cell[226414, 5994, 11221, 306, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237672, 6305, 765, 22, 98, "Input"],
Cell[238440, 6329, 6190, 184, 72, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[244691, 6520, 229, 3, 55, "Subsection"],
Cell[244923, 6525, 469, 8, 96, "Text"],
Cell[CellGroupData[{
Cell[245417, 6537, 998, 29, 71, "Input"],
Cell[CellGroupData[{
Cell[246440, 6570, 731, 15, 33, "Print"],
Cell[247174, 6587, 731, 15, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[247932, 6606, 269, 5, 96, "Text"],
Cell[CellGroupData[{
Cell[248226, 6615, 1859, 59, 98, "Input"],
Cell[250088, 6676, 9230, 267, 90, "Output"],
Cell[259321, 6945, 18262, 492, 238, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[277632, 7443, 199, 4, 55, "Subsection"],
Cell[277834, 7449, 604, 11, 123, "Text"],
Cell[CellGroupData[{
Cell[278463, 7464, 780, 26, 71, "Input"],
Cell[CellGroupData[{
Cell[279268, 7494, 759, 15, 33, "Print"],
Cell[280030, 7511, 757, 15, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[280836, 7532, 668, 20, 71, "Input"],
Cell[281507, 7554, 134505, 3587, 495, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416049, 11146, 923, 25, 98, "Input"],
Cell[416975, 11173, 82267, 2169, 379, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[499291, 13348, 114, 1, 55, "Subsection"],
Cell[499408, 13351, 247, 5, 69, "Text"],
Cell[CellGroupData[{
Cell[499680, 13360, 801, 17, 98, "Input"],
Cell[CellGroupData[{
Cell[500506, 13381, 640, 12, 33, "Print"],
Cell[501149, 13395, 640, 12, 33, "Print"],
Cell[501792, 13409, 632, 12, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[502473, 13427, 535, 17, 43, "Input"],
Cell[503011, 13446, 32106, 940, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535154, 14391, 584, 15, 98, "Input"],
Cell[535741, 14408, 23510, 744, 156, "Output"]
}, Open  ]],
Cell[559266, 15155, 481, 8, 70, "Text"],
Cell[559750, 15165, 1103, 35, 71, "Input"],
Cell[CellGroupData[{
Cell[560878, 15204, 789, 22, 43, "Input"],
Cell[561670, 15228, 13903, 460, 126, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[575622, 15694, 107, 1, 55, "Subsection"],
Cell[575732, 15697, 215, 5, 69, "Text"],
Cell[CellGroupData[{
Cell[575972, 15706, 1245, 30, 71, "Input"],
Cell[CellGroupData[{
Cell[577242, 15740, 732, 13, 33, "Print"],
Cell[577977, 15755, 724, 13, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[578750, 15774, 791, 22, 43, "Input"],
Cell[579544, 15798, 13669, 404, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[593250, 16207, 686, 18, 98, "Input"],
Cell[593939, 16227, 8104, 263, 69, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[602092, 16496, 140, 1, 55, "Subsection"],
Cell[602235, 16499, 550, 10, 148, "Text"],
Cell[CellGroupData[{
Cell[602810, 16513, 2705, 82, 179, "Input"],
Cell[CellGroupData[{
Cell[605540, 16599, 1262, 23, 33, "Print"],
Cell[606805, 16624, 1264, 23, 33, "Print"],
Cell[608072, 16649, 1252, 22, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[609373, 16677, 719, 24, 43, "Input"],
Cell[610095, 16703, 33042, 899, 191, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[643174, 17607, 819, 22, 98, "Input"],
Cell[643996, 17631, 28864, 830, 191, "Output"]
}, Open  ]],
Cell[672875, 18464, 520, 9, 95, "Text"],
Cell[673398, 18475, 1461, 46, 98, "Input"],
Cell[CellGroupData[{
Cell[674884, 18525, 1030, 31, 71, "Input"],
Cell[675917, 18558, 12767, 399, 117, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[688733, 18963, 111, 1, 55, "Subsection"],
Cell[688847, 18966, 659, 12, 175, "Text"],
Cell[689509, 18980, 219, 4, 43, "Text"],
Cell[CellGroupData[{
Cell[689753, 18988, 832, 26, 71, "Input"],
Cell[690588, 19016, 692, 14, 33, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691317, 19035, 777, 23, 43, "Input"],
Cell[692097, 19060, 17611, 518, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[709745, 19583, 467, 14, 43, "Input"],
Cell[710215, 19599, 15846, 483, 124, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[726122, 20089, 104, 1, 106, "Section"],
Cell[726229, 20092, 456, 7, 70, "Text"],
Cell[CellGroupData[{
Cell[726710, 20103, 125, 2, 43, "Input"],
Cell[CellGroupData[{
Cell[726860, 20109, 260, 4, 33, "Print"],
Cell[727123, 20115, 534, 12, 33, "Print"],
Cell[727660, 20129, 330, 5, 61, "Print"],
Cell[727993, 20136, 260, 4, 33, "Print"],
Cell[728256, 20142, 417, 6, 88, "Print"],
Cell[728676, 20150, 260, 4, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[728963, 20158, 1681, 37, 125, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
